import { Text, View, TouchableOpacity, Dimensions, FlatList, Appearance, Alert } from 'react-native'
import React, { useState, useEffect } from 'react'
import Ionicons from 'react-native-vector-icons/Ionicons'

import { authentication } from '../../../firebaseConfig'
import { db } from '../../../firebaseConfig'
import { collection, onSnapshot, deleteDoc, doc, updateDoc, deleteField, getDoc, increment, getDocs } from 'firebase/firestore'

import CardExercise from './CardExercise'

import hpStyles from '../hpStyles'
import hpStylesDark from '../hpStylesDark'

const {width, height} = Dimensions.get('screen')

export default function CardDay(props) {

    const colorScheme = Appearance.getColorScheme()

    const [ planifications, setPlanifications ] = useState([])
    const [ notes, setNotes] = useState()
   
    useEffect(() => {
        getData()
      }, []) 

    const getData = async () => {

            onSnapshot(collection(db, "users", authentication.currentUser.uid, "weekDay", props.day, "exercises"), async (querySnapshot) => {
                let plans = []
                let id = 0
                querySnapshot.forEach((doc) => {
                    let notes = doc.data().notes
                    notes.sort((a,b) => {
                        return a.noteDay - b.noteDay
                    })
                    plans.push({id: id, exerciseByBot: doc.data().exerciseByBot, exerciseName: doc.data().exerciseName, series: doc.data().series, notes: notes, order: doc.data().order})
                    id = id + 1       
                })
                plans.sort((a,b) => {
                    return a.order - b.order
                })
                if ( plans.length != 0) {
                    getNotes()
                } else {
                    //deleteNotes()
                    setNotes(undefined)
                }
                setPlanifications(plans)
            })
        
    }

    /*const deleteNotes = async () => {
        const docRef = doc(db, "users", authentication.currentUser.uid, "weekDay", props.day)
        const docSnap = await getDoc(docRef)
        if (docSnap.exists()) {
            await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.day), {
                note: deleteField()
            })
        }
    }*/

    const getNotes = async () => {
        const docRef = doc(db, "users", authentication.currentUser.uid, "weekDay", props.day)
        const docSnap = await getDoc(docRef)
        if (docSnap.exists()) {
            setNotes(docSnap.data().note)
        }
    }

    const clearExercises = () => {
        Alert.alert(
            "Vas a eliminar todos los ejercicios del " + props.day + " ¿Quieres continuar?",
            "También va a eliminarse la información de Astro en caso de que te la haya añadido",
            [ { text: "Cancelar", style: "cancel" }, { text: "Continuar" , onPress: () => onDelete()} ]
        )
    }

    const onDelete = async () => {
        /*planifications.forEach(async element => {
            await deleteDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.day, "exercises", element.exerciseName))
            await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.day), {
                nExercises: increment(-1)
            })
            const docRef = doc(db, "users", authentication.currentUser.uid, "weekDay", props.day)
            const docSnap = await getDoc(docRef)
            if (docSnap.exists()) {
                if (docSnap.data().nExercises == 0) {
                    await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.day), {
                        nExercises: deleteField()
                    })
                    
                }
            }
        })
        deleteNotes()*/
        const docRef = doc(db, "users", authentication.currentUser.uid, "weekDay", props.day)
        const docSnap = await getDoc(docRef)
        if (docSnap.exists()) { 
            await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.day), {
                nExercises: deleteField()
            })
            await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.day), {
                note: deleteField()
            })
            const querySnapshot = await getDocs(collection(db, "users", authentication.currentUser.uid, "weekDay", props.day, "exercises"))
            querySnapshot.forEach(async (docum) => {
                await deleteDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.day, "exercises", docum.data().exerciseName))
            })
        }
        
        Alert.alert(
            "Tus ejercicios se han eliminado correctamente",
            "",
            [ { text: "OK" } ]
        )
    }

    const showInfo = () => {
        Alert.alert(
            notes,
            "",
            [ { text: "OK" } ]
        )
    }

    const showInfo2 = () => {
        Alert.alert(
            "Para eliminar la información de Astro, elimina antes todos los ejercicios del " + props.day,
            "",
            [ { text: "OK" } ]
        )
    }

    const renderCardExercise = ({ item, index }) => (
        <CardExercise plan={false} id={item.id} exerciseByBot={item.exerciseByBot} exerciseName={item.exerciseName} series={item.series} day={props.day} notes={item.notes} order={item.order}/>
    )
    
    return (
        <TouchableOpacity style={{ height: height,width: width, alignItems: 'center'}} activeOpacity={1}>
            <TouchableOpacity activeOpacity={1} style={colorScheme === 'dark' ? hpStylesDark.cardView : hpStyles.cardView}>
                <View style={{flexDirection:'row', width: '100%', alignItems: 'center'}}>
                    <Text style={colorScheme === 'dark' ? hpStylesDark.titleCardDay : hpStyles.titleCardDay}>{props.day}</Text>
                    {notes != undefined && 
                        <View style={{flex: 1, alignItems: 'flex-end', marginRight: 13}}>
                            <TouchableOpacity onPress={() => showInfo()} onLongPress={() => showInfo2()}>
                                    <Ionicons name="ios-information-circle-outline" size={25} color={'orange'}/>
                                </TouchableOpacity>
                        </View>
                    }
                    {notes == undefined &&
                        <View style={{flex: 1, alignItems: 'flex-end', marginRight: 13}}>
                            
                        </View>
                    }
                        {planifications.length != 0 &&
                            <View style={{marginRight: 20}}>
                                <TouchableOpacity onPress={() => clearExercises()}>
                                    <Ionicons name="ios-refresh" size={25} color={'red'}/>
                                </TouchableOpacity> 
                            </View>
                        }   
                </View>
                {planifications.length != 0 &&
                    <FlatList
                        style={hpStyles.cardExerciseFlatListView}
                        data={planifications}
                        renderItem={renderCardExercise}
                        key={item => item.id}
                        
                        />
                }
                {planifications.length == 0 &&
                    <View style={hpStyles.noExsView}>
                        <Ionicons name="ios-information-circle-outline" size={25} color={'gray'} />
                        <Text style={hpStyles.noExsLabel}>Tus ejercicios se mostrarán aquí</Text>
                    </View>
                }
            </TouchableOpacity>
        </TouchableOpacity>
    )
}