import { Text, View, TouchableOpacity, Appearance, Alert } from 'react-native'
import { useState } from 'react'
import Ionicons from 'react-native-vector-icons/Ionicons'

import { authentication } from '../../../firebaseConfig'
import { db } from '../../../firebaseConfig'
import { doc, deleteDoc } from "firebase/firestore"

import HomePlanModal from '../Modals/HomePlanModal'
import UpdateNameModal from '../Modals/UpdateNameModal'

import hpStyles from '../hpStyles'
import hpStylesDark from '../hpStylesDark'

export default function CardWithPlan(props) {

    const colorScheme = Appearance.getColorScheme()

    const [ planModal, setPlanModal ] = useState(false)
    const [ updateNameModal, setUpdateNameModal ] = useState(false)

    const deleteCardWithPlan = () => {
        if ( props.namePlan == "PIP Plan" || props.namePlan == "PIE Plan") {
            Alert.alert(
                "¿Quieres eliminar la planificación?",
                "",
                [ { text: "Cancelar", style: "cancel" }, { text: "Eliminar" , onPress: () => onDelete(true)}]
            )
        } else {
            Alert.alert(
                "¿Que quieres hacer?",
                "",
                [ { text: "Cancelar", style: "cancel" }, { text: "Cambiar nombre de la planificación" , onPress: () => setUpdateNameModal(!updateNameModal)}, { text: "Eliminar planificación" , onPress: () => onDelete()}]
            )
        }
    }

    const onDelete = async (value = false) => {

        if ( value ) {
            await deleteDoc(doc(db, "users", authentication.currentUser.uid, "planifications", props.exerciseName))
        } else {
            Alert.alert(
                "¿Seguro que quieres eliminar tu planificación?",
                "",
                [ { text: "Cancelar", style: "cancel" }, { text: "Eliminar" , onPress: async () => await deleteDoc(doc(db, "users", authentication.currentUser.uid, "planifications", props.exerciseName))}]
            )
        }
        
    }

    return (
        <View style={hpStyles.cardWithPlanView}>
            {props.id != 0 && 
                <View style={colorScheme === 'dark' ? hpStylesDark.separator : hpStyles.separator}></View>
            }
            <View style={{flexDirection: 'row', alignItems: 'center',}}>
                <Text style={hpStyles.cardWithoutPlanViewTitleText}>{props.exerciseName.toUpperCase()}</Text>
                <TouchableOpacity style={hpStyles.cardWithoutPlanViewTitleIconView} onPress={() => deleteCardWithPlan()}>
                    <Ionicons name="ios-create-outline" size={25} color={colorScheme === 'dark' ? '#fff' : 'black'} />
                </TouchableOpacity>
            </View>
            <TouchableOpacity style={hpStyles.btnOpenPlan} onPress={() => setPlanModal(!planModal)}><Text style={hpStyles.btnOpenPlanText} numberOfLines={1}>{props.namePlan}</Text></TouchableOpacity>
            <HomePlanModal planModal={planModal} setPlanModal={setPlanModal} planification={props.planification}/>
            <UpdateNameModal updateNameModal={updateNameModal} setUpdateNameModal={setUpdateNameModal} exerciseName={props.exerciseName}/>
        </View>
    )
}