import { Text, View, TouchableOpacity, FlatList, Appearance, Alert } from 'react-native'
import { useState } from 'react'
import Ionicons from 'react-native-vector-icons/Ionicons'

import hpStyles from '../hpStyles'

import { authentication } from '../../../firebaseConfig'
import { db } from '../../../firebaseConfig'
import { doc, deleteDoc, updateDoc, increment, deleteField, getDoc, getDocs, collection } from "firebase/firestore"

import AddSerieModal from '../Modals/AddSerieModal'
import NotesModal from '../Modals/NotesModal'
import ChangeOrderModal from '../Modals/ChangeOrderModal'
import CardWithoutPlanSerie from './CardWithoutPlanSerie'
import hpStylesDark from '../hpStylesDark'

export default function CardWithoutPlan(props) {

    const [ addSerieModal, setAddSerieModal ] = useState(false)
    const [ notesModal, setNotesModal ] = useState(false)
    const [ updateNameModal, setUpdateNameModal ] = useState(false)
    const [ changeOrderModal, setChangeOrderModal] = useState(false)

    const colorScheme = Appearance.getColorScheme()
    
    const renderSerie = ({ item, index }) => (
        <CardWithoutPlanSerie serie={item.id} reps={item.reps} weight={item.weight} weekDay={props.day} exerciseName={props.exerciseName} series={props.series} exerciseByBot={props.exerciseByBot}/>
    )

    const options = () => {
        Alert.alert(
            "¿Que quieres hacer?",
            "",
            [ { text: "Cancelar", style: "cancel" }, { text: "Añadir serie" , onPress: () => setAddSerieModal(!addSerieModal) }, { text: "Eliminar ejercicio" , onPress: () => deleteCardWithoutPlan() } ]
        )

    }

    const deleteCardWithoutPlan = () => {
        Alert.alert(
            "¿Seguro que quieres eliminar tu ejercicio?",
            "",
            [ { text: "Cancelar", style: "cancel" }, { text: "Eliminar" , onPress: () => onDelete()} ]
        )
    }

    const onDelete = async () => {
        let o = props.order
        await deleteDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.day, "exercises", props.exerciseName))
        await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.day), {
            nExercises: increment(-1)
        })
        const docRef = doc(db, "users", authentication.currentUser.uid, "weekDay", props.day)
        const docSnap = await getDoc(docRef)
        if (docSnap.exists()) {
            if (docSnap.data().nExercises <= 0) {
                await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.day), {
                    nExercises: deleteField()
                })
            }
        }
        const querySnapshot = await getDocs(collection(db, "users", authentication.currentUser.uid, "weekDay", props.day, "exercises"))
        querySnapshot.forEach(async (docSnapchot) => {
            if ( o < docSnapchot.data().order) {
                await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.day, "exercises", docSnapchot.data().exerciseName), {
                    order: increment(-1)
                })
            }
        })
    }

    return (
        <TouchableOpacity style={hpStyles.cardWithoutPlanView} activeOpacity={1}>
            {props.order != 1 &&
                <View style={colorScheme === 'dark' ? hpStylesDark.separator : hpStyles.separator}></View>
            }
            <View style={hpStyles.cardWithoutPlanViewTitle}>
                <Text style={hpStyles.cardWithoutPlanViewTitleText} numberOfLines={2}>{props.exerciseName.toUpperCase()}</Text>
                
                {colorScheme === 'light' && 
                    <View style={{flexDirection: 'row', flex: 1, justifyContent: 'space-between'}}>
                        <TouchableOpacity onPress={() => setChangeOrderModal(!changeOrderModal)}>
                            <Ionicons name="ios-swap-vertical" size={25} color={'black'}/>
                        </TouchableOpacity>
                        <TouchableOpacity onPress={() => setNotesModal(!notesModal)} style={{marginLeft: 3}}>
                            <Ionicons name="ios-document-text-outline" size={25} color={'black'}/>
                        </TouchableOpacity> 
                        <TouchableOpacity  onPress={() => options()} style={{marginLeft: 3}}>
                            <Ionicons name="ios-create-outline" size={25} color={'black'}/>
                        </TouchableOpacity> 
                    </View>
                }
                {colorScheme === 'dark' && 
                    <View style={{flexDirection: 'row', flex: 1, justifyContent: 'space-between'}}>
                        <TouchableOpacity onPress={() => setChangeOrderModal(!changeOrderModal)}>
                            <Ionicons name="ios-swap-vertical" size={25} color={'#fff'}/>
                        </TouchableOpacity>
                        <TouchableOpacity onPress={() => setNotesModal(!notesModal)} style={{marginLeft: 3}}>
                            <Ionicons name="ios-document-text-outline" size={25} color={'#fff'}/>
                        </TouchableOpacity> 
                        <TouchableOpacity  onPress={() => options()} style={{marginLeft: 3}}>
                            <Ionicons name="ios-create-outline" size={25} color={'#fff'}/>
                        </TouchableOpacity> 
                    </View>
                }
                <ChangeOrderModal changeOrderModal={changeOrderModal} setChangeOrderModal={setChangeOrderModal} weekDay={props.day} actualOrder={props.order} exerciseName={props.exerciseName}/>
                <NotesModal notesModal={notesModal} setNotesModal={setNotesModal} exerciseName={props.exerciseName} notes={props.notes} weekDay={props.day}/>
                <AddSerieModal addSerieModal={addSerieModal} setAddSerieModal={setAddSerieModal} actualSeries={props.series} exerciseName={props.exerciseName} weekDay={props.day}/>
            </View>
            <FlatList 
                style={hpStyles.cardWithoutPlanFlatList}
                data={props.series}
                renderItem={renderSerie}
                key={item => item.id}
                horizontal={true}
                showsHorizontalScrollIndicator={false}
                />
        </TouchableOpacity>
    )
}