import { Text, View, TouchableOpacity, Alert, Appearance } from 'react-native'
import { useState } from 'react'

import { authentication } from '../../../firebaseConfig'
import { db } from '../../../firebaseConfig'
import { doc, updateDoc } from 'firebase/firestore'

import UpdateRepsModal from '../Modals/UpdateRepsModal'
import UpdateWeightModal from '../Modals/UpdateWeightModal'

import hpStyles from '../hpStyles'
import hpStylesDark from '../hpStylesDark'

export default function CardWithoutPlanSerie(props) {

    const [ updateWeightModal, setUpdateWeightModal ] = useState(false)
    const [ updateRepsModal, setUpdateRepsModal ] = useState(false)

    const colorScheme = Appearance.getColorScheme()

    const changeState = () => {
        if ( props.weight == "undefined") {
            Alert.alert(
                "¿Quieres modificar el peso de tu serie?",
                "",
                [ { text: "Cancelar", style: "cancel" }, { text: "Modificar", onPress: () => setUpdateWeightModal(!updateWeightModal) } ]
            )
        } else {
            if ( props.exerciseByBot == 1 ) {
                Alert.alert(
                    "¿Que valor quieres modificar?",
                    "",
                    [ { text: "Cancelar", style: "cancel" }, { text: "Peso", onPress: () => setUpdateWeightModal(!updateWeightModal) }, { text: "Eliminar serie", onPress: () => deleteSerie() } ]
                )
            } else {
                Alert.alert(
                    "¿Que valor quieres modificar?",
                    "",
                    [ { text: "Cancelar", style: "cancel" }, { text: "Repeticiones", onPress: () => setUpdateRepsModal(!updateRepsModal) }, { text: "Peso", onPress: () => setUpdateWeightModal(!updateWeightModal) }, { text: "Eliminar serie", onPress: () => deleteSerie() } ]
                )
            }
        }
    }

    const deleteSerie = () => {
        Alert.alert(
            "Seguro que quieres eliminar tu serie?",
            "",
            [ { text: "Cancel", style: "cancel" }, { text: "Eliminar", onPress: () => onDeleteSerie() } ]
        )
    }

    const onDeleteSerie = async () => {
        let temp = props.series.filter(a => 
            a.id != props.serie
        )
        let idTemp = 0
        const newList = temp.map((item) => {
            const updatedItem = {
                ...item,
                id: idTemp,
            }
            idTemp = idTemp + 1
            return updatedItem
          })
        await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.weekDay, "exercises", props.exerciseName), {
            "series": newList
        })
    }

    return (
        <TouchableOpacity style={colorScheme === 'dark' ? hpStylesDark.cardWithoutPlanSerieView2 : hpStyles.cardWithoutPlanSerieView} onLongPress={() => changeState()}>
            <Text style={colorScheme === 'dark' ? hpStylesDark.cardWithoutPlanSerieTitle: hpStyles.cardWithoutPlanSerieTitle}>Serie {props.serie + 1}</Text>
            <View style={colorScheme === 'dark' ? hpStylesDark.separator2 : hpStyles.separator2}/>
            {props.weight == "amrap" &&
                <Text style={colorScheme === 'dark' ? hpStylesDark.cardWithoutPlanSerieWeighte: hpStyles.cardWithoutPlanSerieWeighte}>Al fallo</Text>
            }
            {props.weight != "amrap" &&
                <Text style={colorScheme === 'dark' ? hpStylesDark.cardWithoutPlanSerieReps: hpStyles.cardWithoutPlanSerieReps}>{props.reps} rep/s</Text>
            }
            {props.weight == "undefined" &&
                <Text style={colorScheme === 'dark' ? hpStylesDark.cardWithoutPlanSerieWeighte: hpStyles.cardWithoutPlanSerieWeighte}>Sin definir</Text>
            }
            {props.weight != "undefined" &&
                <Text style={colorScheme === 'dark' ? hpStylesDark.cardWithoutPlanSerieWeighte: hpStyles.cardWithoutPlanSerieWeighte}>{props.weight} kg/s</Text>
            }
            <UpdateRepsModal updateRepsModal={updateRepsModal} setUpdateRepsModal={setUpdateRepsModal} actualReps={props.reps} weekDay={props.weekDay} exerciseName={props.exerciseName} series={props.series} serie={props.serie} weight={props.weight}/>
            <UpdateWeightModal updateWeightModal={updateWeightModal} setUpdateWeightModal={setUpdateWeightModal} reps={props.reps} weekDay={props.weekDay} exerciseName={props.exerciseName} series={props.series} serie={props.serie} actualWeight={props.weight}/>
        </TouchableOpacity>
        
    )
}