import { FlatList, View, Appearance } from 'react-native'
import { useEffect, useRef, useState } from 'react'

import CardDay from './HomeCards/CardDay'
import hpStyles from './hpStyles'
import hpStylesDark from './hpStylesDark'

export default function HomePage() {

  const colorScheme = Appearance.getColorScheme()

    const [ days, setDays ] = useState(['Lunes', 'Martes', 'Miercoles', 'Jueves', 'Viernes', 'Sabado', 'Domingo'])
    const flatListRef = useRef()

    const renderDay = ({ item, index }) => (
        <CardDay day={item}/>
    )

    return (
        <View style={colorScheme === 'dark' ? hpStylesDark.container : hpStyles.container}>
          <FlatList 
              ref={flatListRef}
              data={days}
              renderItem={renderDay}
              key={item => item.id}
              horizontal
              pagingEnabled
              showsHorizontalScrollIndicator={false}
              snapToAlignment='center'
              initialScrollIndex={new Date().getDay() === 0 ? 6 : new Date().getDay() - 1}
              onScrollToIndexFailed={({
                index,
                averageItemLength,
              }) => {
                // Layout doesn't know the exact location of the requested element.
                // Falling back to calculating the destination manually
                flatListRef.current?.scrollToOffset({
                  offset: index * averageItemLength,
                  animated: true,
                })
              }}
              />
        </View>
    )
  }