import { Button, View, Modal, FlatList, Appearance, TouchableOpacity, Text, Alert, TextInput} from 'react-native';
import React, { useState, useEffect } from 'react';
import Ionicons from 'react-native-vector-icons/Ionicons';

import { authentication } from '../../../firebaseConfig'
import { db } from '../../../firebaseConfig'
import { setDoc, doc, updateDoc, increment } from 'firebase/firestore'

import hpStyles from '../hpStyles'
import hpStylesDark from '../hpStylesDark'

export default function AddSerieModal(props) {

    const [ reps, setReps ] = useState("")
    const [ weight, setWeight ] = useState("")

    const colorScheme = Appearance.getColorScheme()

    const confirm = () => {
        const repsRegex = new RegExp(/^\d{1,3}$|^\((\d{1,2} - \d{1,2})\)$|^\((\d{1,2}-\d{1,2})\)$|^\((\d{1,2}- \d{1,2})\)$|^\((\d{1,2} -\d{1,2})\)$/)
        const weightRegex = new RegExp(/^\d{1,3}$|^\d{1,3},\d{1,2}$/)
        if ( reps == "" ){
            Alert.alert(
                "Tu serie no tiene repeticiones",
                "",
                [ { text: "OK" } ]
            )
        } else if ( !repsRegex.test(reps) ) {
            Alert.alert(
                "Formato incorrecto de tu serie",
                "Las repeticiones de tu ejercicio han de ser un valor de 3 dígitos como máximo o un conjunto de valores, por ejemplo (8 - 12)",
                [ { text: "OK" } ]
            )
        } else if ( weight == "" ) {
            Alert.alert(
                "Tu serie no tiene peso",
                "",
                [ { text: "OK" } ]
            )
        } else if ( !weightRegex.test(weight) ) {
            Alert.alert(
                "Formato incorrecto de tu serie",
                "El peso de tu ejercicio ha de ser un número de 1 a 3 dígitos con o sin decimales, máx. 2 decimales",
                [ { text: "OK" } ]
            )
        } else {
            Alert.alert(
                "Vas a añadir una serie. Quieres continuar?",
                "",
                [ { text: "Cancelar", style: "cancel" }, { text: "Continuar", onPress: () => update() } ]
            )
        }
    };

    const update = async () => {
        let temp = props.actualSeries
        temp.push({id: props.actualSeries.at(-1).id + 1, reps: reps, weight: weight})
        setReps("")
        setWeight("")
        props.setAddSerieModal(!props.addSerieModal)
        await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.weekDay, "exercises", props.exerciseName), {
            "series": temp
        })
    }

    const closeModal = () => {
        setReps("")
        setWeight("")
        props.setAddSerieModal(!props.addSerieModal)
    }
    
    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={props.addSerieModal}
            onRequestClose={() => { closeModal() }}
            >
            <View style={colorScheme === 'dark' ? hpStylesDark.modelView : hpStyles.modelView}>
                <View style={hpStyles.modelViewButtons}>
                        <Button title="Cancelar" onPress={() => closeModal()}/>
                        <Button title="Confirmar" onPress={() => confirm()}/>  
                </View>
                <View style={colorScheme === 'dark' ? hpStylesDark.seriesView : hpStyles.seriesView}>
                    <Text style={colorScheme === 'dark' ? hpStylesDark.seriesViewLabel : hpStyles.seriesViewLabel}>Serie {props.actualSeries.at(-1).id + 2}</Text>
                    <TextInput style={colorScheme === 'dark' ? hpStylesDark.serieInputStyle2 : hpStyles.serieInputStyle2} placeholder="Repeticiones" keyboardType='numbers-and-punctuation' maxLength={9} onChangeText={(value) => setReps(value)}/>
                    <View style={hpStyles.serieInputView}>
                        <TextInput style={colorScheme === 'dark' ? hpStylesDark.serieInputStyle : hpStyles.serieInputStyle} placeholder="Kg" keyboardType='numeric' maxLength={6} onChangeText={(value) => setWeight(value)}/>
                    </View>
                </View>              
            </View>
        </Modal>
    )
}