import { Button, View, Modal, Appearance, Alert, TextInput } from 'react-native'
import { useEffect, useState } from 'react'
import {Picker} from '@react-native-picker/picker'

import { authentication } from '../../../firebaseConfig'
import { db } from '../../../firebaseConfig'
import { doc, updateDoc, getDoc, onSnapshot, query, where, getDocs, collection } from 'firebase/firestore'

import hpStyles from '../hpStyles'
import hpStylesDark from '../hpStylesDark'

export default function ChangeOrderModal(props) {

    const [ orderPos, setOrderPos] = useState(1)
    const [ options, setOptions] = useState([])
    const [ flag, setFlag] = useState(false)

    const colorScheme = Appearance.getColorScheme()

    useEffect(() => {
        getNExercises()
    }, [])

    useEffect(() => {
        getNExercises()
    }, [props.changeOrderModal, flag])

    const getNExercises = async() => {
        let items = undefined
        const docRef = doc(db, "users", authentication.currentUser.uid, "weekDay", props.weekDay)
        const docSnap = await getDoc(docRef)
        if ( docSnap.exists() ) {
            items = Array.from({length: docSnap.data().nExercises}, (_, i) => i + 1)
        }
        setOptions(items)
    }

    const closeModal = () => {
        props.setChangeOrderModal(!props.changeOrderModal)
        setFlag(!flag)
    }

    const checkOrder = () => {
        if ( orderPos == props.actualOrder) {
            Alert.alert(
                "Ejercicio en la misma posición",
                "Selecciona otra posición",
                [ { text: "OK" } ]
            )
        } else {
            Alert.alert(
                "Vas a modificar el orden ¿Quieres continuar?",
                "Se va a intercambiar el ejercicio '" + props.exerciseName + "' por el que esta en la posición " + orderPos,
                [ { text: "Cancelar" , style: 'cancel'}, {text: "Continuar", onPress: () => changeOrder()} ]
            )
        }
    }

    const changeOrder = async () => {
        const q = query(collection(db, "users", authentication.currentUser.uid, "weekDay", props.weekDay, "exercises"), where("order", "==", orderPos))
        const querySnapshot = await getDocs(q);
        querySnapshot.forEach(async (docSnapshot) => {
            await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.weekDay, "exercises", docSnapshot.id), {
                order: props.actualOrder
            })
        })
        await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.weekDay, "exercises", props.exerciseName), {
            order: orderPos
        })
        setFlag(!flag)
        closeModal()
        Alert.alert(
            "Modificación correcta",
            "",
            [ { text: "OK" } ]
        )
    }
    
    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={props.changeOrderModal}
            onRequestClose={() => { closeModal() }}
            >
            <View style={colorScheme === 'dark' ? hpStylesDark.modelView : hpStyles.modelView}>
                <View style={hpStyles.modelViewButtons}>
                        <Button title="Cancelar" onPress={() => closeModal()}/>
                        <Button title="Confirmar" onPress={() => checkOrder()}/>  
                </View>
                <Picker
                    itemStyle={colorScheme === 'dark' ? {height:140 ,fontSize: 20, color: '#fff'} : {height:140 ,fontSize: 20,}}
                    selectedValue={orderPos}
                    onValueChange={(itemValue, itemIndex) =>
                        setOrderPos(itemValue)
                    }>
                    {options.map((option) => {return <Picker.Item label={"Posición " + option} value={option} key={option}/>})}
                </Picker>
            </View>
        </Modal>
    )
}