import { View, Modal, Text, TextInput, TouchableOpacity, Alert, Appearance, Button, FlatList } from 'react-native'
import { useEffect, useState } from 'react'
import Ionicons from 'react-native-vector-icons/Ionicons'
import DateTimePicker from '@react-native-community/datetimepicker'

import CardNote from '../HomeCards/CardNote'

import { authentication } from '../../../firebaseConfig'
import { db } from '../../../firebaseConfig'
import { doc, deleteDoc, updateDoc } from "firebase/firestore"

import hpStyles from '../hpStyles'
import hpStylesDark from '../hpStylesDark'

export default function NotesModal(props) {

    const colorScheme = Appearance.getColorScheme()
    
    const [textNote, setTextNote] = useState("");

    const [ noteDay, setNoteDay ] = useState(new Date())
    const onChange = (event, selectedDate) => {
        const currentDate = selectedDate
        setNoteDay(currentDate)
    }
    
    const renderNote = ({ item, index }) => (
        <CardNote day={item.noteDay.toDate().getDate()} month={item.noteDay.toDate().getMonth()} year={item.noteDay.toDate().getFullYear()} text={item.textNote} notes={props.notes} id={item.id} weekDay={props.weekDay} exerciseName={props.exerciseName}/>
    )

    const checkNote = () => {
        if ( textNote == "") {
            Alert.alert(
                "Nota vacía",
                "Introduce algún texto para guardar la nota",
                [ { text: "OK" } ]
            )
        } else {
            let repeated = false
            props.notes.forEach(element => {
                if ( element.noteDay.toDate().getDate() == noteDay.getDate() && element.noteDay.toDate().getMonth() == noteDay.getMonth() && element.noteDay.toDate().getFullYear() == noteDay.getFullYear() ) {
                    repeated = true
                }
            });
            if ( repeated ) {
                Alert.alert(
                    "Día repetido",
                    "No puedes asignar una nota el mismo día que otra del mismo ejercicio",
                    [ { text: "OK" } ]
                )
            } else {
                Alert.alert(
                    "¿Quieres guardar esta nota?",
                    "",
                    [ { text: "Cancelar", style: 'cancel' }, {text: "Guardar", onPress: () => saveNote()} ]
                )
            }
        }
    }

    const saveNote = async () => {
        let notes = props.notes
        const len = props.notes.length
        if ( len == 0 ) {
            notes.push({id: 0, noteDay: noteDay, textNote: textNote})
        } else {
            notes.push({id: len, noteDay: noteDay, textNote: textNote})
        }
        await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.weekDay, "exercises", props.exerciseName ), {
            notes: notes
        })
        setTextNote("")
        setNoteDay(new Date())
    }

    const closeModal = () => {
        props.setNotesModal(!props.notesModal)
        setTextNote("")
        setNoteDay(new Date())
    }

    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={props.notesModal}
            onRequestClose={() => closeModal() }
            >
            <View style={colorScheme === 'dark' ? hpStylesDark.notesModalViwe : hpStyles.notesModalViwe}>
                <TouchableOpacity style={{flexDirection: 'row', alignItems: 'center'}} onPress={() => closeModal()}>
                    <Ionicons name="ios-chevron-back" size={25} color={'#0080FE'} />
                    <Text style={{color: '#0080FE', fontSize: 16,}}>Página principal</Text>
                </TouchableOpacity>
                <View style={hpStyles.notesModelView2}>
                    <Text style={{color: 'gray'}} numberOfLines={1}>NOTAS: {props.exerciseName.toUpperCase()}</Text>
                    <View style={colorScheme === 'dark' ? hpStylesDark.notesModelNotesView : hpStyles.notesModelNotesView}>
                        {props.notes.length == 0 && 
                            <View style={{flex: 1, alignItems: 'center', justifyContent: 'center'}}>
                                <Ionicons name="ios-information-circle-outline" size={25} color={'gray'} />
                                <Text style={{color: 'gray'}}>Tus notas se mostrarán aquí</Text>
                            </View>
                        }
                        {props.notes.length != 0 && 
                            <FlatList 
                                data={props.notes}
                                renderItem={renderNote}
                                key={item => item.id}
                                horizontal={true}
                                />
                        }
                    </View>
                    <View style={colorScheme === 'dark' ? hpStylesDark.notesModelNotesView2 : hpStyles.notesModelNotesView2}>
                        <View style={{flexDirection: 'row', alignItems: 'center', marginBottom: 10,}}>
                            <Text style={colorScheme === 'dark' ? hpStylesDark.noteLabel : hpStyles.noteLabel}>Fecha de la anotación</Text>
                            <DateTimePicker
                                style={{height: 35, width: 123,}}
                                testID="dateTimePicker"
                                value={noteDay}
                                mode='date'
                                is24Hour={true}
                                onChange={onChange}
                            />
                        </View>
                        <View style={ colorScheme === 'dark' ? hpStylesDark.separator : hpStyles.separator}/>
                        <View>
                            <Text style={colorScheme === 'dark' ? hpStylesDark.noteLabel2 : hpStyles.noteLabel2}>Descripción</Text>
                            <TextInput style={colorScheme === 'dark' ? hpStylesDark.noteInput : hpStyles.noteInput} placeholderTextColor='gray' placeholder='Escribe aquí tu texto' multiline={true} value={textNote} onChangeText={(text) => setTextNote(text)}/>
                        </View>
                    </View>
                    <View style={{marginTop: 10,}}>
                        <Button title='Añadir nota' onPress={() => checkNote()}></Button>
                    </View>
                </View>
            </View>
        </Modal>
    )
}