import { Button, View, Modal, Appearance, Alert, TextInput } from 'react-native'

import { authentication } from '../../../firebaseConfig'
import { db } from '../../../firebaseConfig'
import { doc, deleteDoc, updateDoc } from "firebase/firestore"

import { useState } from 'react'
import hpStyles from '../hpStyles'
import hpStylesDark from '../hpStylesDark'

export default function TextModal(props) {

    const [newText, setNewText] = useState(props.text)

    const colorScheme = Appearance.getColorScheme()

    const closeModal = () => {
        setNewText(props.text)
        props.setTextModal(!props.textModal)
    }

    const onEdit = () => {

        if ( newText == props.text ) {
            Alert.alert(
                "Sin cambios para subir",
                "",
                [ {text: "OK"} ]
            )
        } else {
            Alert.alert(
                "¿Quieres editar tu nota?",
                "",
                [ { text: "Cancelar", style:'cancel' }, {text: "Editar", onPress: () => updateNote()} ]
            )
        }
    }

    const updateNote = async () => {
        let temp = props.notes.map((c,i) => {
            if ( c.id == props.id ) {
                return {id: c.id, noteDay: c.noteDay, textNote: newText}
            } else {
                return c
            }
        })
        await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.weekDay, "exercises", props.exerciseName ), {
            notes: temp
        })
        setNewText(newText)
        Alert.alert(
            "Nota editada correctamente",
            "",
            [ {text: "OK"} ]
        )
    }
    
    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={props.textModal}
            onRequestClose={() => { closeModal() }}
            >
            <View style={colorScheme === 'dark' ? hpStylesDark.modelViewText : hpStyles.modelViewText}>
                <View style={hpStyles.modelViewButtons}>
                    <Button title="Volver" onPress={() => closeModal()}/> 
                    <Button title="Editar" onPress={() => onEdit()}/> 
                </View>
                <View style={{marginTop: 25, paddingHorizontal: 10,}}>
                    <TextInput style={colorScheme === 'dark' ? hpStylesDark.inputText : hpStyles.inputText} placeholderTextColor='gray' value={newText} multiline={true} placeholder='Escribe aquí tu texto' onChangeText={(value) => setNewText(value)}></TextInput>
                </View>
            </View>
        </Modal>
    )
}