import { Button, View, Modal, Appearance, Alert, TextInput } from 'react-native'
import { useState } from 'react'

import { authentication } from '../../../firebaseConfig'
import { db } from '../../../firebaseConfig'
import { doc, updateDoc } from 'firebase/firestore'

import hpStyles from '../hpStyles'
import hpStylesDark from '../hpStylesDark'

export default function UpdateNameModal(props) {

    const [ newName, setNewName ] = useState("")

    const colorScheme = Appearance.getColorScheme()

    const confirm = () => {
        if ( newName == "" ) {
            Alert.alert(
                "Introduce algun nombre",
                "",
                [ { text: "OK"} ]
            )
        } else {
            Alert.alert(
                "Vas a modificar el nombre de tu planificación. ¿Quieres continuar?",
                "",
                [ { text: "Cancelar", style: "cancel" }, { text: "Continuar", onPress: () => update() } ]
            )
        }
    }

    const update = async () => {
        closeModal()
        await updateDoc( doc(db, "users", authentication.currentUser.uid, "planifications", props.exerciseName), {
            namePlan: newName,
        })
    }

    const closeModal = () => {
        setNewName("")
        props.setUpdateNameModal(!props.updateNameModal)
    }
    
    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={props.updateNameModal}
            onRequestClose={() => { closeModal() }}
            >
            <View style={colorScheme === 'dark' ? hpStylesDark.modelViewWText : hpStyles.modelViewWText}>
                <View style={hpStyles.modelViewButtons}>
                        <Button title="Cancelar" onPress={() => closeModal()}/>
                        <Button title="Confirmar" onPress={() => confirm()}/>  
                </View>
                {colorScheme == 'light' && 
                    <View style={hpStyles.btnAddSeriesView}>   
                        <TextInput style={{fontSize: 16, borderBottomColor: '#e7e7e7', borderBottomWidth: 1, width: '100%'}} placeholder="Nuevo nombre de tu planificación" maxLength={30} value={newName} onChangeText={(value) => setNewName(value)}/> 
                    </View>
                }
                {colorScheme == 'dark' && 
                    <View style={hpStyles.btnAddSeriesView}>   
                        <TextInput style={{fontSize: 16, color: '#fff', borderBottomColor: '#313133', borderBottomWidth: 1, width: '100%'}} placeholder="Nuevo nombre de tu planificación" maxLength={30} value={newName} onChangeText={(value) => setNewName(value)}/> 
                    </View>
                }
            </View>
        </Modal>
    )
}