import { Button, View, Modal, Appearance, TextInput, Alert } from 'react-native'
import { useState } from 'react'
import Ionicons from 'react-native-vector-icons/Ionicons'

import { authentication } from '../../../firebaseConfig'
import { db } from '../../../firebaseConfig'
import { doc, updateDoc } from 'firebase/firestore'

import hpStyles from '../hpStyles'
import hpStylesDark from '../hpStylesDark'

export default function UpdateRepsModal(props) {

    const [ newReps, setNewReps ] = useState("")

    const colorScheme = Appearance.getColorScheme()

    const confirm = () => {
        const repsRegex = new RegExp(/^\d{1,3}$|^\((\d{1,2} - \d{1,2})\)$|^\((\d{1,2}-\d{1,2})\)$|^\((\d{1,2}- \d{1,2})\)$|^\((\d{1,2} -\d{1,2})\)$/)
        if (newReps == "") {
            Alert.alert(
                "Introduce algun peso",
                "",
                [ { text: "OK"} ]
            )
        } else if ( !repsRegex.test(newReps) ) {
            Alert.alert(
                "Formato incorrecto de tu serie",
                "Las repeticiones de tu ejercicio han de ser un valor de 3 dígitos como máximo o un conjunto de valores, por ejemplo (8 - 12)",
                [ { text: "OK" } ]
            )
        } else {
            Alert.alert(
                "Vas a modificar las repeticiones de tu serie. ¿Quieres continuar?",
                "",
                [ { text: "Cancelar", style: "cancel" }, { text: "Continuar", onPress: () => update() } ]
            )
        }
    }

    const update = async () => {
        let temp = props.series.map((c,i) => {
            if ( i == props.serie ) {
                return {id: i, reps: newReps, weight: props.weight}
            } else {
                return c
            }
        })
        setNewReps("")
        props.setUpdateRepsModal(!props.updateRepsModal)
        await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.weekDay, "exercises", props.exerciseName), {
            "series": temp
        })
    }

    const closeModal = () => {
        setNewReps("")
        props.setUpdateRepsModal(!props.updateRepsModal)
    }
    
    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={props.updateRepsModal}
            onRequestClose={() => { closeModal() }}
            >
            <View style={colorScheme === 'dark' ? hpStylesDark.modelViewWText : hpStyles.modelViewWText}>
                <View style={hpStyles.modelViewButtons}>
                        <Button title="Cancelar" onPress={() => closeModal()}/>
                        <Button title="Confirmar" onPress={() => confirm()}/>  
                </View>
                {colorScheme == 'light' && 
                    <View style={hpStyles.btnAddSeriesView}>   
                        <TextInput style={{fontSize: 16, borderBottomColor: '#e7e7e7', borderBottomWidth: 1, width: '100%'}} placeholder="Repeticiones" keyboardType='numbers-and-punctuation' maxLength={9} value={newReps} onChangeText={(value) => setNewReps(value)}/> 
                    </View>
                }
                {colorScheme == 'dark' && 
                    <View style={hpStyles.btnAddSeriesView}>   
                        <TextInput style={{fontSize: 16, color: '#fff', borderBottomColor: '#313133', borderBottomWidth: 1, width: '100%'}} placeholder="Repeticiones" keyboardType='numbers-and-punctuation' maxLength={9} value={newReps} onChangeText={(value) => setNewReps(value)}/> 
                    </View>
                }
            </View>
        </Modal>
    )
}