import { Button, View, Modal, Appearance, Alert, TextInput } from 'react-native'
import { useState } from 'react'

import { authentication } from '../../../firebaseConfig'
import { db } from '../../../firebaseConfig'
import { doc, updateDoc } from 'firebase/firestore'

import hpStyles from '../hpStyles'
import hpStylesDark from '../hpStylesDark'

export default function UpdateWeightModal(props) {

    const [ newWeight, setNewWeight ] = useState("")

    const colorScheme = Appearance.getColorScheme()

    const confirm = () => {
        const weightRegex = new RegExp(/^\d{1,3}$|^\d{1,3},\d{1,2}$/)
        if ( newWeight == "" ) {
            Alert.alert(
                "Introduce algun peso",
                "",
                [ { text: "OK"} ]
            )
        } else if ( !weightRegex.test(newWeight) ) {
            Alert.alert(
                "Formato incorrecto de tu serie",
                "El peso de tu ejercicio ha de ser un número de 1 a 3 dígitos con o sin decimales, máx. 2 decimales",
                [ { text: "OK" } ]
            )
        } else {
            Alert.alert(
                "Vas a modificar el peso de tu serie. ¿Quieres continuar?",
                "",
                [ { text: "Cancelar", style: "cancel" }, { text: "Continuar", onPress: () => update() } ]
            )
        }
    }

    const update = async () => {
        let temp = props.series.map((c,i) => {
            if ( i == props.serie ) {
                return {id: i, reps: props.reps, weight: newWeight}
            } else {
                return c
            }
        })
        setNewWeight("")
        props.setUpdateWeightModal(!props.updateWeightModal)
        await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", props.weekDay, "exercises", props.exerciseName), {
            "series": temp
        })   
    }

    const closeModal = () => {
        setNewWeight("")
        props.setUpdateWeightModal(!props.updateWeightModal)
    }
    
    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={props.updateWeightModal}
            onRequestClose={() => { closeModal() }}
            >
            <View style={colorScheme === 'dark' ? hpStylesDark.modelViewWText : hpStyles.modelViewWText}>
                <View style={hpStyles.modelViewButtons}>
                        <Button title="Cancelar" onPress={() => closeModal()}/>
                        <Button title="Confirmar" onPress={() => confirm()}/>  
                </View>
                {colorScheme == 'light' && 
                    <View style={hpStyles.btnAddSeriesView}>   
                        <TextInput style={{fontSize: 16, borderBottomColor: '#e7e7e7', borderBottomWidth: 1, width: '100%'}} placeholder="Kg" keyboardType='numeric' maxLength={6} value={newWeight} onChangeText={(value) => setNewWeight(value)}/> 
                    </View>
                }
                {colorScheme == 'dark' && 
                    <View style={hpStyles.btnAddSeriesView}>   
                        <TextInput style={{fontSize: 16, color: '#fff', borderBottomColor: '#313133', borderBottomWidth: 1, width: '100%'}} placeholder="Kg" keyboardType='numeric' maxLength={6} value={newWeight} onChangeText={(value) => setNewWeight(value)}/> 
                    </View>
                }
            </View>
        </Modal>
    )
}