import { FlatList, Text, View, Appearance } from 'react-native'
import { useState, useEffect } from 'react'
import Ionicons from 'react-native-vector-icons/Ionicons'

import { authentication } from '../../firebaseConfig'
import { db } from '../../firebaseConfig'
import { collection, getDocs, onSnapshot } from 'firebase/firestore'

import CardExercise from '../HomePage/HomeCards/CardExercise'

import planViewStyles from './planViewStyles'
import planViewStylesDark from './planViewStylesDark'

export default function PlanViewPage() {

    const colorScheme = Appearance.getColorScheme()

    const [ planificaciones, setPlanificaciones ] = useState([])

    useEffect(() => {
        getData()
    }, [])

    const getData = async () => {
        onSnapshot(collection(db, "users", authentication.currentUser.uid, "planifications"), (querySnapshot) => {
            let plans = []
            let id = 0
            querySnapshot.forEach((doc) => {
                plans.push({plan: true, id: id, exerciseName: doc.data().exerciseName, namePlan: doc.data().namePlan, planification: doc.data().planification})
                id = id + 1       
            })            
            setPlanificaciones(plans)
        })
    }

    const renderCardPlan = ({ item, index }) => (
        <CardExercise plan={item.plan} id={item.id} exerciseName={item.exerciseName} item={item}/>
    )

    return (
        <View style={colorScheme === 'dark' ? planViewStylesDark.container : planViewStyles.container}>
            <View style={planViewStyles.planViewTitle}>
                <Text style={colorScheme === 'dark' ? planViewStylesDark.planViewText : planViewStyles.planViewText}>Tus planificaciones</Text>
            </View>
            {planificaciones.length == 0 && 
                <View style={planViewStyles.noPlansView}>
                    <Ionicons name="ios-information-circle-outline" size={25} color={'gray'} />
                    <Text style={planViewStyles.noPlansLabel}>Tus planificaciones se mostrarán aquí</Text>
                </View>
            }
            {planificaciones.length != 0 && 
                <View style={colorScheme === 'dark' ? planViewStylesDark.listView : planViewStyles.listView}>
                <FlatList
                    style={planViewStyles.cardExerciseFlatListView}
                    data={planificaciones}
                    renderItem={renderCardPlan}
                    key={item => item.id}
                    scrollEnabled={false}
                    />
                </View>
            }
        </View>
    )
  }