import { useState } from 'react'
import { Text, View, Switch, Appearance } from 'react-native'
import DateTimePicker from '@react-native-community/datetimepicker'

import BasicoDefaultPlan from './BasicPlanTypes/BasicoDefaultPlan'
import BasicoYourPlan from './BasicPlanTypes/BasicoYourPlan'

import plStyles from '../../plStyles'
import plStylesDark from '../../plStylesDark'

export default function PlanType(props) {

    const colorScheme = Appearance.getColorScheme()

    const [ startDayPlan, setStartDayPlan ] = useState(new Date())

    const [ defaultPlan, setDefaultPlan] = useState(true)
    const toggleSwitch = () => setDefaultPlan(previousState => !previousState)

    const onChange = (event, selectedDate) => {
        const currentDate = selectedDate
        setStartDayPlan(currentDate)
    }

    return (
        <View style={plStyles.containerBasicoConPlan}>
            <View style={colorScheme === 'dark' ? plStylesDark.iosWrapView : plStyles.iosWrapView}>
                <View style={plStyles.dateTimePickerView}>
                    <Text style={colorScheme === 'dark' ? plStylesDark.dateTimePickerLabel : plStyles.dateTimePickerLabel}>Comienzo de la planificación</Text>
                    <DateTimePicker
                        style={colorScheme === 'dark' ? plStylesDark.dateTimerPickerStyle : plStyles.dateTimerPickerStyle}
                        testID="dateTimePicker"
                        value={startDayPlan}
                        mode='date'
                        is24Hour={true}
                        onChange={onChange}
                    />
                </View>
                <View style={colorScheme === 'dark' ? plStylesDark.separator : plStyles.separator}/>
                <View style={plStyles.switchDefaultPlanView}>
                    <Text style={colorScheme === 'dark' ? plStylesDark.switchDefaultPlanLabel : plStyles.switchDefaultPlanLabel} >Planificación por defecto</Text>
                    <Switch style={plStyles.switchDefaultPlanStyle}
                        trackColor={{ false: "#767577", true: "#32CD32" }}
                        thumbColor={defaultPlan ? "#f4f3f4" : "#f4f3f4"}
                        ios_backgroundColor="#3e3e3e"
                        onValueChange={toggleSwitch}
                        value={defaultPlan}/>
                </View>
                <View style={colorScheme === 'dark' ? plStylesDark.separator : plStyles.separator}/>
            </View>
            {defaultPlan && <BasicoDefaultPlan exerciseName={props.exerciseName} startDayPlan={startDayPlan} /> }
            {!defaultPlan && <BasicoYourPlan exerciseName={props.exerciseName} startDayPlan={startDayPlan} setStartDayPlan={setStartDayPlan}/> }
        </View>
    )
}