import { Button, Text, View, FlatList, TouchableOpacity, Alert, Appearance } from 'react-native'
import { useState } from 'react'
import Ionicons from 'react-native-vector-icons/Ionicons'

import Serie from '../../PlannerCards/Serie'
import WeekDayModal from '../../Modals/WeekDayModal'

import plStyles from '../../plStyles'

export default function BasicoSinPlan(props) {

    const colorScheme = Appearance.getColorScheme()

    // Modal
    const [ dayModal, setDayModal ] = useState(false)

    // Series 
    const [ nSeries, setNSeries ] = useState(0)
    const [ seriesList, setSeriesList ] = useState([{id: 0, reps: "", weight: ""}, ])

    const manageConfirm = () => { 
        let ok = true
        const repsRegex = new RegExp(/^\d{1,3}$|^\((\d{1,2} - \d{1,2})\)$|^\((\d{1,2}-\d{1,2})\)$|^\((\d{1,2}- \d{1,2})\)$|^\((\d{1,2} -\d{1,2})\)$/)
        const weightRegex = new RegExp(/^\d{1,3}$|^\d{1,3},\d{1,2}$/)
        if ( nSeries == 0) {
            Alert.alert(
                "No tienes series",
                "Añade alguna serie a tu ejercicio",
                [ { text: "OK" } ]
            )
            ok = false
        } else {
            let repsToZero = true
            let repsRegexTest = true
            let weightToZero = true
            let weightRegexTest = true
            console.log("-----------------------------------------")
            seriesList.forEach(element => {
                console.log(element," - Regex reps: ",repsRegex.test(element.reps), " Regex weight: ",weightRegex.test(element.weight))
                if ( element.reps == "") {
                    repsToZero = false
                } else if ( !repsRegex.test(element.reps)) {
                    repsRegexTest = false
                } else if ( element.weight == "") {
                    weightToZero = false
                } else if ( !weightRegex.test(element.weight)) {
                    weightRegexTest = false
                }
            })
            if ( !repsToZero ) {
                Alert.alert(
                    "Faltan repeticiones",
                    "Tu planificación del ejercicio debe tener almenos alguna repetición como mínimo en cada serie",
                    [ { text: "OK" } ]
                )
                ok = false
            } else if ( !repsRegexTest ) {
                Alert.alert(
                    "Formato incorrecto de tu serie",
                    "Las repeticiones de tu ejercicio han de ser un valor de 3 dígitos como máximo o un conjunto de valores, por ejemplo (8 - 12)",
                    [ { text: "OK" } ]
                )
                ok = false
            } else if ( !weightToZero ) {
                Alert.alert(
                    "Serie sin peso",
                    "Tu planificación del ejercicio debe tener almenos algún peso que levantar como mínimo en cada serie",
                    [ { text: "OK" } ]
                )
                ok = false
            } else if ( !weightRegexTest ) {
                Alert.alert(
                    "Formato incorrecto de tu serie",
                    "El peso de tu ejercicio ha de ser un número de 1 a 3 dígitos con o sin decimales, máx. 2 decimales",
                    [ { text: "OK" } ]
                )
                ok = false
            }
        }
        

        if ( ok ) {
            setDayModal(!dayModal);
        }  
    }

    // Serie management
    const renderSerie = ({ item }) => (
        <Serie id={item.id} reps={item.reps} weight={item.weight} seriesList={seriesList} setSeriesList={setSeriesList}/>
    )

    const addSerie = () => {
        if ( nSeries == 0 ) {
            setSeriesList([{id: 0, reps: "", weight:""}, ])
            setNSeries(nSeries + 1)
        } else if ( nSeries + 1 <= 12 ) {
            const newList = seriesList.concat({id: seriesList.at(-1).id + 1, reps: "", weight:""})
            setSeriesList(newList)
            setNSeries(nSeries + 1)
        }  
    }

    const removeSerie = () => {
        if ( nSeries > 0 ) {  
            const newList = seriesList.filter((item) => item.id !== seriesList.at(-1).id)
            setSeriesList(newList)
            setNSeries(nSeries - 1)
        }
    }

    return (
        <View style={plStyles.containerBasicoSinPlan}>
            <View style={plStyles.seriesView}>
                <Text style={plStyles.nSeriesLabel}>{nSeries} SERIES</Text>
                {colorScheme === 'light' &&
                    <View style={plStyles.btnAddSeriesView}>   
                        <TouchableOpacity onPress={() => removeSerie()}>
                            <Ionicons name="ios-remove" size={20} color={'cian'}/>
                        </TouchableOpacity>
                        <TouchableOpacity onPress={() => addSerie()} style={{marginLeft: 35,}}>
                            <Ionicons name="ios-add" size={20} color={'cian'}/>
                        </TouchableOpacity>  
                    </View>
                }
                {colorScheme === 'dark' &&
                    <View style={plStyles.btnAddSeriesView}>   
                        <TouchableOpacity onPress={() => removeSerie()}>
                            <Ionicons name="ios-remove" size={20} color={'#fff'}/>
                        </TouchableOpacity>
                        <TouchableOpacity onPress={() => addSerie()} style={{marginLeft: 35,}}>
                            <Ionicons name="ios-add" size={20} color={'#fff'}/>
                        </TouchableOpacity>  
                    </View>
                }
            </View>
            { nSeries == 0 &&
                <View style={plStyles.noPlanView}>
                    <View style={plStyles.noPlanView2}>
                        <Ionicons name="ios-information-circle-outline" size={25} color={'gray'} />
                        <Text style={plStyles.noPlanLabel}>Empieza añadiendo series</Text>
                    </View>
                </View>
            }
            { nSeries > 0 &&
                <FlatList
                    data={seriesList}
                    renderItem={renderSerie}
                    key={item => item.id}
                /> 
            }
            <View style={plStyles.btnConfirmar}>
                    <Button title="Confirmar" onPress={() => manageConfirm()}></Button>
            </View>  
            <WeekDayModal dayModal={dayModal} setDayModal={setDayModal} exerciseName={props.exerciseName} series={seriesList} setSeriesList={setSeriesList} setNSeries={setNSeries} typeExercise={0}/>   
        </View>
    )
}