import { Button, View, Modal, Alert, Appearance} from 'react-native'
import { useEffect, useState } from 'react'
import {Picker} from '@react-native-picker/picker'

import { authentication } from '../../../firebaseConfig'
import { db } from '../../../firebaseConfig'
import { setDoc, doc, getDoc, collection, updateDoc, increment, onSnapshot } from 'firebase/firestore'

import plStyles from '../plStyles'
import plStylesDark from '../plStylesDark'

export default function WeekDayModal(props) {

    const colorScheme = Appearance.getColorScheme()

    const [ weekDay, setWeekDay ] = useState("Lunes")
    const [order, setOrder] = useState()

    useEffect(() => {
        getOrder()
    }, [weekDay, props.dayModal])

    const checkPush = () => {
        Alert.alert(
            "Se va a añadir un ejercicio para el " + weekDay + " ¿Quieres continuar?",
            "",
            [ {text: "Cancelar", style: "cancel"}, { text: "Continuar", onPress: () => pushData() } ]
        )
    }

    const getOrder = async () => {
        const docRef = doc(db, "users", authentication.currentUser.uid, "weekDay", weekDay)
        const docSnap = await getDoc(docRef)
        if (docSnap.exists() && docSnap.data().nExercises != undefined) {
            setOrder(docSnap.data().nExercises + 1)
        } else {
            setOrder(1)
        }
        
    }

    const pushData = async () => {
        if (order == 1) {
            await setDoc( doc(db, "users", authentication.currentUser.uid, "weekDay", weekDay), {
                nExercises: order
            })
        } else {
            await updateDoc(doc(db, "users", authentication.currentUser.uid, "weekDay", weekDay), {
                nExercises: increment(1)
            })
        }
        await setDoc( doc(db, "users", authentication.currentUser.uid, "weekDay", weekDay, "exercises", props.exerciseName), {
            exerciseByBot: 0,
            exerciseName: props.exerciseName,
            series: props.series,
            notes: [],
            order: order,
        })
        props.setSeriesList([])
        props.setNSeries(0)
        if ( props.typeExercise == 1) {
            props.setExerciseName("")
        }
        props.setDayModal(!props.dayModal)
        Alert.alert(
            "Ejercicio añadido correctamente",
            "Podrás visualizar tu ejercicio en la página principal de la aplicación",
            [ {text: "OK"} ]
        )
    }
    
    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={props.dayModal}
            onRequestClose={() => { props.setDayModal(!props.dayModal) }}
            >
            <View style={colorScheme === 'dark' ? plStylesDark.modelView : plStyles.modelView}>
                <View style={plStyles.modelViewButtons}>
                    <Button title="Cancelar" onPress={() => props.setDayModal(!props.dayModal)}/>
                    <Button title="Confirmar" onPress={() => checkPush()}/>  
                </View>
                {colorScheme === 'light' &&
                    <Picker
                        itemStyle={{height:140 ,fontSize: 20,}}
                        selectedValue={weekDay}
                        onValueChange={(itemValue, itemIndex) =>
                            setWeekDay(itemValue)
                        }>
                        <Picker.Item label="Lunes" value="Lunes" />
                        <Picker.Item label="Martes" value="Martes" />
                        <Picker.Item label="Miércoles" value="Miercoles" />
                        <Picker.Item label="Jueves" value="Jueves" />
                        <Picker.Item label="Viernes" value="Viernes" />
                        <Picker.Item label="Sábado" value="Sabado" />
                        <Picker.Item label="Domingo" value="Domingo" />
                    </Picker>
                }
                {colorScheme === 'dark' &&
                    <Picker
                        itemStyle={{height:140 ,fontSize: 20, color: '#fff'}}
                        selectedValue={weekDay}
                        onValueChange={(itemValue, itemIndex) =>
                            setWeekDay(itemValue)
                        }>
                        <Picker.Item label="Lunes" value="Lunes" />
                        <Picker.Item label="Martes" value="Martes" />
                        <Picker.Item label="Miércoles" value="Miercoles" />
                        <Picker.Item label="Jueves" value="Jueves" />
                        <Picker.Item label="Viernes" value="Viernes" />
                        <Picker.Item label="Sábado" value="Sabado" />
                        <Picker.Item label="Domingo" value="Domingo" />
                    </Picker>
                }
            </View>
        </Modal>
    )
}