import { Button, View, Modal, Text, TouchableWithoutFeedback, Keyboard, FlatList, Alert, TouchableOpacity, Appearance } from 'react-native'
import React, { useState, useEffect } from 'react'

import DayYourPlanCard from '../PlannerCards/DayYourPlanCard'
import Ionicons from 'react-native-vector-icons/Ionicons'

import plStyles from '../plStyles'
import plStylesDark from '../plStylesDark'

export default function YourPlanModal(props) {

    const colorScheme = Appearance.getColorScheme()

    const [ nDays, setNDays ] = useState(1)
    const [ planification, setPlanification ] = useState([{id: 0, day: props.startDayPlan, series:[]}, ])

    useEffect(() => {
        setPlanification([{id: 0, day: props.startDayPlan, series:[]}, ])
        setNDays(1)
    }, [props.startDayPlan]) 

    useEffect(() => {
        if ( props.planification == undefined){
            setPlanification([{id: 0, day: props.startDayPlan, series:[]}, ])
            setNDays(1)
        } else {
            setPlanification(props.planification)
            setNDays(props.planification.length)
        }
    }, [props.planification]) 

    const DismissKeyboard = ({children}) => (
        <TouchableWithoutFeedback onPress={() => Keyboard.dismiss()}>
            {children}
        </TouchableWithoutFeedback>
    )

    const renderDays = ({ item }) => (
        <DayYourPlanCard id={item.id} day={item.day} actualItem={item} planification={planification} goodPlan={props.planification}/>
    )

    const addDay = () => {
        const newList = planification.concat({id: planification.at(-1).id + 1, day: undefined, series: []})
        setPlanification(newList)
        setNDays(nDays + 1)
    }

    const removeDay = () => {
        if ( nDays > 1 ) {
            const newList = planification.filter((item) => item.id !== planification.at(-1).id)
            setPlanification(newList)
            setNDays(nDays - 1)
        }
    }

    const btnConfirm = () => { 
        let dayPlan = false
        let dayPlanSchedule = false
        let seriesList = false
        let seriesListReps = false
        let seriesListRepsRegexp = false
        let seriesListWeight = false
        let seriesListWeightRegexp = false
        const repsRegex = new RegExp(/^\d{1,3}$|^\((\d{1,2} - \d{1,2})\)$|^\((\d{1,2}-\d{1,2})\)$|^\((\d{1,2}- \d{1,2})\)$|^\((\d{1,2} -\d{1,2})\)$/)
        const weightRegex = new RegExp(/^\d{1,3}$|^\d{1,3},\d{1,2}$/)
        let prevDay = props.startDayPlan
        planification.map((element, index) => {
            if (element.day == undefined) {
                dayPlan = true
            } else if (index >= 1 && !dayPlan) {
                if (element.day.getFullYear() < prevDay.getFullYear()) {
                    dayPlanSchedule = true
                } else if(element.day.getFullYear() == prevDay.getFullYear()){
                    if (element.day.getMonth() < prevDay.getMonth()) {
                        dayPlanSchedule = true
                    } else if (element.day.getMonth() == prevDay.getMonth()) {
                        if (element.day.getDate() <= prevDay.getDate()) {
                            dayPlanSchedule = true
                        }
                    }
                }
            }
            let cont = 0
            element.series.map((element2, index2) => {
                if (element2.reps == "") {
                    seriesListReps = true
                } else if (!repsRegex.test(element2.reps)) {
                    seriesListRepsRegexp = true
                } else if (element2.weight == "") {
                    seriesListWeight = true
                } else if (!weightRegex.test(element2.weight)) {
                    seriesListWeightRegexp = true
                }
                cont = cont + 1
            })
            if ( cont == 0 ) {
                seriesList = true
            }
            prevDay = element.day
        })

        if ( dayPlan ) {
            Alert.alert(
                "Día sin especificar",
                "Tu planificación del ejercicio debe tener un día asignado para poder realizarla",
                [ { text: "OK" } ]
            )
        } else if ( dayPlanSchedule) {
            Alert.alert(
                "Planificación mal gestionada",
                "Tu planificación del ejercicio debe seguir un orden cronológico. Ej: DÍA 2 no puede hacerse un dia superior o igual al DÍA 1",
                [ { text: "OK" } ]
            )
        } else if ( seriesList ) {
            Alert.alert(
                "Día sin series",
                "Tu planificación del ejercicio debe tener mas de 1 serie por dia para poder realizarla",
                [ { text: "OK" } ]
            )
        } else if ( seriesListReps ) {
            Alert.alert(
                "Serie sin repeticiones",
                "Tu planificación de la serie debe tener mas de 1 repeticion para poder realizarla",
                [ { text: "OK" } ]
            )
        } else if ( seriesListRepsRegexp ) {
            Alert.alert(
                "Formato incorrecto de tu serie",
                "Las repeticiones de tu ejercicio han de ser un valor de 3 dígitos como máximo o un conjunto de valores, por ejemplo (8 - 12)",
                [ { text: "OK" } ]
            )
        } else if ( seriesListWeight ) {
            Alert.alert(
                "Serie sin peso",
                "Tu planificación de la serie debe tener algún peso para poder realizarla",
                [ { text: "OK" } ]
            )
        } else if ( seriesListWeightRegexp ) {
            Alert.alert(
                "Formato incorrecto de tu serie",
                "El peso de tu ejercicio ha de ser un número de 1 a 3 dígitos con o sin decimales, máx. 2 decimales",
                [ { text: "OK" } ]
            )
        }
        

        if ( !dayPlan && !dayPlanSchedule && !seriesList && !seriesListReps && !seriesListWeight && !seriesListRepsRegexp && !seriesListWeightRegexp) {
            Alert.alert(
                "Vas a crear una planificación ¿Quieres continuar?",
                "",
                [ {text: "Cancelar", style: "cancel"}, { text: "Continuar" ,onPress: () => addPlan() } ]
            )
        }
    }

    const addPlan = () => {
        props.setPlanification(planification)
        props.setYourPlanModal(!props.yourPlanModal)
    }

    const closeModal = () => {
        if (props.planification == undefined) {
            setPlanification([{id: 0, day: props.startDayPlan, series:[]}, ])
            setNDays(1)
            props.setYourPlanModal(!props.yourPlanModal)
        } else {
            props.setYourPlanModal(!props.yourPlanModal)
        }
    }

    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={props.yourPlanModal}
            onRequestClose={() => { props.setYourPlanModal(!props.yourPlanModal) }}
            >
            <DismissKeyboard>
                <View style={colorScheme === 'dark' ? plStylesDark.modelYourPlanView : plStyles.modelYourPlanView}>
                    <View style={plStyles.modelYourPlanView2}>
                    {colorScheme === 'light' && 
                        <View style={plStyles.modelCloseTitleView}>
                            <TouchableOpacity  onPress={() => closeModal()}><Ionicons name="ios-chevron-back" size={25} color={'#0080FE'}/></TouchableOpacity>
                            <Text style={plStyles.modelTextTitle}>Tu propio plan</Text>
                            <Ionicons name="ios-chevron-back" size={25} color={'#f2f1f6'} />
                        </View>
                    }
                    {colorScheme === 'dark' && 
                        <View style={plStyles.modelCloseTitleView}>
                            <TouchableOpacity  onPress={() => closeModal()}><Ionicons name="ios-chevron-back" size={25} color={'#0080FE'}/></TouchableOpacity>
                            <Text style={colorScheme === 'dark' ? plStylesDark.modelTextTitle : plStyles.modelTextTitle}>Tu propio plan</Text>
                            <Ionicons name="ios-chevron-back" size={25} color={'#000000'} />
                        </View>
                    }
                        <View style={colorScheme === 'dark' ? plStylesDark.modelDaysLabel : plStyles.modelDaysLabel}>
                            <Text style={colorScheme === 'dark' ? plStylesDark.modelDaysText : plStyles.modelDaysText}>Días de tu plan:   {nDays} día/s</Text>
                            {colorScheme === 'light' &&
                                <View style={plStyles.btnAddSeriesViewYourPlan}>   
                                    <TouchableOpacity onPress={() => removeDay()}>
                                        <Ionicons name="ios-remove" size={20} color={'cian'}/>
                                    </TouchableOpacity>
                                    <TouchableOpacity onPress={() => addDay()} style={{marginLeft: 35,}}>
                                        <Ionicons name="ios-add" size={20} color={'cian'}/>
                                    </TouchableOpacity>
                                </View>
                            }
                            {colorScheme === 'dark' &&
                                <View style={plStyles.btnAddSeriesViewYourPlan}>   
                                    <TouchableOpacity onPress={() => removeDay()}>
                                        <Ionicons name="ios-remove" size={20} color={'#fff'}/>
                                    </TouchableOpacity>
                                    <TouchableOpacity onPress={() => addDay()} style={{marginLeft: 35,}}>
                                        <Ionicons name="ios-add" size={20} color={'#fff'}/>
                                    </TouchableOpacity>
                                </View>
                            }
                        </View>
                        <FlatList 
                            data={planification}
                            renderItem={renderDays}
                            key={item => item.id}
                            />
                        <View style={plStyles.btnConfirmar2}>
                            <Button title="Confirmar" onPress={() => btnConfirm()}></Button>
                        </View>   
                    </View>
                </View>
            </DismissKeyboard>
        </Modal>
    )
}