import {Text, View, TouchableOpacity, FlatList, Appearance} from 'react-native'
import React, { useState, useEffect } from 'react'
import Ionicons from 'react-native-vector-icons/Ionicons'

import DayModal from '../Modals/DayModal'
import DayYourSeriesCard from './DayYourSeriesCard'
import plStyles from '../plStyles'
import plStylesDark from '../plStylesDark'

export default function DayYourPlanCard(props) {

    const colorScheme = Appearance.getColorScheme()

    const [ nSeries, setNSeries ] = useState(0)
    const [ series, setSeries ] = useState()

    const [ day, setDay ] = useState(props.day)
    const month = ["January","February","March","April","May","June","July","August","September","October","November","December"]
    const [ dayModal, setDayModal] = useState(false)

    useEffect(() => {
        if ( series != undefined ) {
            props.actualItem.series = series 
        }
    }, [series]) 

    useEffect(() => {
        let planDay = props.planification.at(props.id)
        if ( props.id != 0 ) {
            planDay.day = day
        }
    }, [day])

    const renderSerie = ({ item }) => (
        <DayYourSeriesCard id={item.id} reps={item.reps} weight={item.weight} series={series} setSeries={setSeries}/>
    )

    const addSerie = () => {
        if ( nSeries == 0 ) {
            setSeries([{id: 0, reps: "", weight:""}, ])
            setNSeries(nSeries + 1)
        } else if ( nSeries + 1 <= 12 ) {
            const newList = series.concat({id: series.at(-1).id + 1, reps: "", weight:""})
            setSeries(newList)
            setNSeries(nSeries + 1)
        }  
    }

    const removeSerie = () => {
        if ( nSeries > 0 ) {  
            const newList = series.filter((item) => item.id !== series.at(-1).id)
            setSeries(newList)
            setNSeries(nSeries - 1)
        }
    }

    return (
        <TouchableOpacity activeOpacity={1}>
            <View style={{flexDirection: 'row', alignItems: 'center', marginBottom: 5}}>
                <Text style={plStyles.dayYourPlanCardDayLabel}>DÍA {props.id + 1}</Text>
                {props.id != 0 &&
                    <TouchableOpacity onPress={() => setDayModal(!dayModal)}><Ionicons name="ios-calendar" size={20} color={'#0080FE'}/></TouchableOpacity>
                }
                {day != undefined &&
                    <Text style={plStyles.dayYourPlanCardDayLabel2}>[ {month[day.getMonth()].substring(0,3).toLocaleUpperCase()} {day.getDate()} | {day.getFullYear()} ]</Text>
                }
            </View>
            <DayModal dayModal={dayModal} setDayModal={setDayModal} day={day} setDay={setDay}/>
            <TouchableOpacity style={colorScheme === 'dark' ? plStylesDark.dayYourPlanCardView : plStyles.dayYourPlanCardView} activeOpacity={1}>

            <View style={plStyles.seriesViewYourPlan}>
                <Text style={plStyles.nSeriesLabel}>{nSeries} SERIES</Text>
                {colorScheme === 'light' && 
                    <View style={plStyles.btnAddSeriesView}>   
                        <TouchableOpacity onPress={() => removeSerie()}>
                            <Ionicons name="ios-remove" size={20} color={'cian'}/>
                        </TouchableOpacity>
                        <TouchableOpacity onPress={() => addSerie()} style={{marginLeft: 35,}}>
                            <Ionicons name="ios-add" size={20} color={'cian'}/>
                        </TouchableOpacity>
                    </View>
                }
                {colorScheme === 'dark' && 
                    <View style={plStyles.btnAddSeriesView}>   
                        <TouchableOpacity onPress={() => removeSerie()}>
                            <Ionicons name="ios-remove" size={20} color={'#fff'}/>
                        </TouchableOpacity>
                        <TouchableOpacity onPress={() => addSerie()} style={{marginLeft: 35,}}>
                            <Ionicons name="ios-add" size={20} color={'#fff'}/>
                        </TouchableOpacity>
                    </View>
                }
            </View>
                <FlatList 
                    data={series}
                    renderItem={renderSerie}
                    key={item => item.id}
                    />
            </TouchableOpacity>
        </TouchableOpacity>
    )
}