import { View, Text, TextInput, Button, Alert , Appearance } from 'react-native'
import { useState } from 'react'

import { authentication } from '../../firebaseConfig'
import { signInWithEmailAndPassword } from 'firebase/auth'

import usrStyles from './usrStyles'
import usrStylesDark from './usrStylesDark'

export default function Login(props) {

    const colorScheme = Appearance.getColorScheme()

    const [ email, setEmail ] = useState("")
    const [ password, setPassword ] = useState("")

    const checkLogin = () => {
        if ( email == "" ) {
            Alert.alert(
                "Introduce tu dirección de correo electrónico",
                "",
                [ { text: "OK" } ]
            )
        } else if (password == "" ) {
            Alert.alert(
                "Introduce tu contraseña",
                "",
                [ { text: "OK" } ]
            )
        
        } else { onLogin(email, password) }
    }

    const onLogin = (email, password) => {
        signInWithEmailAndPassword(authentication, email, password)
            .then((re) => {

            })
            .catch((error) => {
                console.log(error.code)
                console.log(error.message)
                Alert.alert(
                    "Inicio de sesión fallido",
                    "Error: " + error.code,
                    [ { text: "OK" } ]
                )
            })
    }

  return (
    <View style={colorScheme === 'dark' ? usrStylesDark.loginView : usrStyles.loginView}>
        <View style={usrStyles.userParamsView}>
            <Text style={colorScheme === 'dark' ? usrStylesDark.userParamsLabel : usrStyles.userParamsLabel}>Email</Text>
            <TextInput style={colorScheme === 'dark' ? usrStylesDark.userParamsInput : usrStyles.userParamsInput} placeholder='Introduce tu dirección de correo' autoCapitalize='none' keyboardType='email-address' value={email} onChangeText={(text) => setEmail(text)}></TextInput>
        </View>        
        <View style={usrStyles.pswParamsView}>
            <Text style={colorScheme === 'dark' ? usrStylesDark.pswParamsLabel : usrStyles.pswParamsLabel}>Contraseña</Text>
            <TextInput style={colorScheme === 'dark' ? usrStylesDark.pswParamsInput : usrStyles.pswParamsInput} placeholder='Introduce tu contraseña' secureTextEntry={true} value={password} onChangeText={(text) => setPassword(text)}></TextInput>
        </View>       
        <View style={usrStyles.btnConfirmar}>
            <Button title='Confirmar' onPress={() => checkLogin()}/>
        </View>
        <View style={usrStyles.botonera}>
            <Button title='Registrate ahora' onPress={() => props.setMode(!props.mode)}/>
            {/*<View style={colorScheme === 'dark' ? usrStylesDark.verticalSeparator : usrStyles.verticalSeparator}></View>
            <Button title='Contraseña olvidada' color={'gray'} />*/}
        </View>
    </View>
  )
}
