import { Button, View, Modal, TextInput, Alert, Appearance } from 'react-native'
import { useState } from 'react'

import { authentication } from '../../../firebaseConfig'
import { updateEmail, signInWithEmailAndPassword } from "firebase/auth"

import usrStyles from '../usrStyles'
import usrStylesDark from '../usrStylesDark'

export default function ChangeEmailModal(props) {

    const colorScheme = Appearance.getColorScheme()

    const [ actualEmail, setActualEmail ] = useState("")
    const [ password, setPassword ] = useState("")
    const [ newEmail, setNewEmail ] = useState("")

    const closeModal = () => {
        setActualEmail("")
        setPassword("")
        setNewEmail("")
        props.setChangeEmailModal(!props.changeEmailModal)
    }
    const pushData = async () => {
        if ( authentication.currentUser.email != actualEmail ) {
            Alert.alert(
                "Tu dirección de correo electrónico no coincide",
                "Asegúrate de que tu dirección de correo electrónico actual coincide con el campo introducido",
                [{ text: "OK" } ]
            )
        } else {
            if ( actualEmail == newEmail ) {
                Alert.alert(
                    "Tu dirección de correo electrónico es idéntica a la que vas a cambiar",
                    "Tu nueva dirección de correo electrónico ha de ser distinta a la actual",
                    [{ text: "OK" } ]
                )
            } else if ( newEmail == "" ) {
                Alert.alert(
                    "Introduce tu nueva dirección de correo electrónico",
                    "",
                    [{ text: "OK" } ]
                )
            } else {
                Alert.alert(
                    "Vas a modificar tu dirección de correo electrónico. ¿Deseas continuar?",
                    "",
                    [ { text: "Cancelar", style: "cancel" }, { text: "Continuar" , onPress: () => onChangeEmail()} ]
                )
            }
        }
    }

    const onChangeEmail = () => {
        signInWithEmailAndPassword(authentication, actualEmail, password)
            .then((re) => {
                updateEmail(authentication.currentUser, newEmail).then(() => {
                    closeModal()
                    Alert.alert(
                        "Se ha actualizado tu dirección de correo electrónico correctamente",
                        "",
                        [ { text: "OK" } ]
                    )
                  }).catch((error) => {
                    Alert.alert(
                        "No se ha podido actualizar tu dirección de correo electrónico",
                        "Error: " + error.code,
                        [ { text: "OK" } ]
                    )
                  })
            })
            .catch((error) => {
                Alert.alert(
                    "Tu contraseña no coincide",
                    "Asegurate de que has introducido correctamente tu contraseña",
                    [ { text: "OK" } ]
                )
            })
    }
    
    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={props.changeEmailModal}
            onRequestClose={() => { props.setChangeEmailModal(!props.changeEmailModal) }}
            >
            <View style={colorScheme === 'dark' ? usrStylesDark.changeEmailModelView : usrStyles.changeEmailModelView}>
                <View style={usrStyles.changeEmailModelViewButtons}>
                    <Button title="Cancelar" onPress={() => closeModal()}/>
                    <Button title="Confirmar" onPress={() => pushData()}/>  
                </View>
                <View style={usrStyles.changeEmailModelInputView}>
                    <TextInput style={colorScheme === 'dark' ? usrStylesDark.changeEmailModelInput : usrStyles.changeEmailModelInput} placeholder='Introduce tu dirección de correo' autoCapitalize='none' keyboardType='email-address' value={actualEmail} onChangeText={(text) => setActualEmail(text)}/>
                    <TextInput style={colorScheme === 'dark' ? usrStylesDark.changeEmailModelInput : usrStyles.changeEmailModelInput} placeholder='Introduce tu nueva dirección de correo' autoCapitalize='none' keyboardType='email-address' value={newEmail} onChangeText={(text) => setNewEmail(text)}/>
                    <TextInput style={colorScheme === 'dark' ? usrStylesDark.changeEmailModelInput : usrStyles.changeEmailModelInput} placeholder='Introduce tu contraseña' autoCapitalize='none' secureTextEntry={true} value={password} onChangeText={(text) => setPassword(text)}/>  
                </View>
            </View>
        </Modal>
    )
}