import { Button, View, Modal, TextInput, Alert, Appearance } from 'react-native'
import { useState } from 'react'

import { authentication } from '../../../firebaseConfig'
import { updatePassword , signInWithEmailAndPassword } from "firebase/auth"

import usrStyles from '../usrStyles'
import usrStylesDark from '../usrStylesDark'

export default function ChangePasswordModal(props) {

    const colorScheme = Appearance.getColorScheme()

    const [ actualPassword, setActualPassword ] = useState("")
    const [ newPassword, setNewPassword ] = useState("")

    const closeModal = () => {
        setActualPassword("")
        setNewPassword("")
        props.setChangePasswordModal(!props.changePasswordModal)
    }

    const pushData = async () => {
        if ( newPassword == "" ) {
            Alert.alert(
                "Introduce tu nueva contraseña",
                "",
                [ { text: "OK" } ]
            )
        } else {
            signInWithEmailAndPassword(authentication, authentication.currentUser.email, actualPassword)
            .then(async (re) => {
                Alert.alert(
                    "Vas a modificar tu contraseña. ¿Deseas continuar?",
                    "",
                    [ { text: "Cancelar", style: "cancel" }, { text: "Continuar" , onPress: () => changePassword()} ]
                )
            })
            .catch((error) => {
                Alert.alert(
                    "Tu contraseña no coincide",
                    "Asegurate de que has introducido correctamente tu contraseña actual",
                    [ { text: "OK" } ]
                )
            })
        } 
    }

    const changePassword = () => {
        updatePassword(authentication.currentUser, newPassword)
        .then((re) => {
            closeModal()
            Alert.alert(
                "Tu contraseña se ha actualizado correctamente",
                "",
                [ { text: "OK" } ]
            )
        })
        .catch((error) => {
            Alert.alert(
                "No se ha podido actualizar tu contraseña",
                "Asegúrate de que tu contraseña tiene como mínimo 6 caracteres",
                [ { text: "OK" } ]
            )
        })
        
    }
    
    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={props.changePasswordModal}
            onRequestClose={() => { props.setChangePasswordModal(!props.changePasswordModal); }}
            >
            <View style={colorScheme === 'dark' ? usrStylesDark.changeEmailModelView : usrStyles.changeEmailModelView}>
                <View style={usrStyles.changeEmailModelViewButtons}>
                    <Button title="Cancelar" onPress={() => closeModal()}/>
                    <Button title="Confirmar" onPress={() => pushData()}/>  
                </View>
                <View style={usrStyles.changeEmailModelInputView}>
                    <TextInput style={colorScheme === 'dark' ? usrStylesDark.changeEmailModelInput : usrStyles.changeEmailModelInput} placeholder='Introduce tu contraseña' autoCapitalize='none' secureTextEntry={true} value={actualPassword} onChangeText={(text) => setActualPassword(text)}/>
                    <TextInput style={colorScheme === 'dark' ? usrStylesDark.changeEmailModelInput : usrStyles.changeEmailModelInput} placeholder='Introduce tu nueva contraseña' autoCapitalize='none' secureTextEntry={true} value={newPassword} onChangeText={(text) => setNewPassword(text)}/>
                </View>
            </View>
        </Modal>
    )
}