import { Button, View, Modal, TextInput, Alert, Appearance } from 'react-native'
import { useState } from 'react'

import { authentication } from '../../../firebaseConfig'
import { updateProfile, signInWithEmailAndPassword } from "firebase/auth"

import usrStyles from '../usrStyles'
import usrStylesDark from '../usrStylesDark'

export default function ChangeUserNameModal(props) {

    const colorScheme = Appearance.getColorScheme()

    const [ actualUserName, setUserName ] = useState("")
    const [ password, setPassword ] = useState("")
    const [ newUserName, setNewUserName ] = useState("")

    const closeModal = () => {
        setUserName("")
        setPassword("")
        setNewUserName("")
        props.setChangeUserNameModal(!props.changeUserNameModal)
    }

    const pushData = async () => {
        if ( authentication.currentUser.displayName != actualUserName ) {
            Alert.alert(
                "Tu nombre de usuario no coincide",
                "Asegúrate de que tu nombre de usuario actual coincide con el campo introducido",
                [{ text: "OK" } ]
            )
        } else {
            if ( actualUserName == newUserName ) {
                Alert.alert(
                    "Tu nombre de usuario es idéntico al que vas a cambiar",
                    "Tu nuevo nombre de usuario ha de ser distinto al actual",
                    [{ text: "OK" } ]
                )
            } else if ( newUserName == "" ) {
                Alert.alert(
                    "Introduce tu nuevo nombre de usuario",
                    "",
                    [{ text: "OK" } ]
                )
            } else {
                Alert.alert(
                    "Vas a modificar tu nombre de usuario. ¿Deseas continuar?",
                    "",
                    [ { text: "Cancelar", style: "cancel" }, { text: "Continuar" , onPress: () => onChangeUserName()} ]
                )
            }
        }
    }

    const onChangeUserName = () => {
        signInWithEmailAndPassword(authentication, authentication.currentUser.email, password)
            .then(async (re) => {
                const displayName = newUserName;
                await updateProfile(authentication.currentUser, {displayName})
                closeModal()
                Alert.alert(
                    "Se ha actualizado tu nombre de usuario correctamente",
                    "",
                    [ { text: "OK" } ]
                )
            })
            .catch((error) => {
                Alert.alert(
                    "Tu contraseña no coincide",
                    "Asegurate de que has introducido correctamente tu contraseña",
                    [ { text: "OK" } ]
                )
            })
    }
    
    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={props.changeUserNameModal}
            onRequestClose={() => { props.setChangeUserNameModal(!props.changeUserNameModal) }}
            >
            <View style={colorScheme === 'dark' ? usrStylesDark.changeEmailModelView : usrStyles.changeEmailModelView}>
                <View style={usrStyles.changeEmailModelViewButtons}>
                    <Button title="Cancelar" onPress={() => closeModal()}/>
                    <Button title="Confirmar" onPress={() => pushData()}/>  
                </View>
                <View style={usrStyles.changeEmailModelInputView}>
                    <TextInput style={colorScheme === 'dark' ? usrStylesDark.changeEmailModelInput : usrStyles.changeEmailModelInput} placeholder='Introduce tu nombre de usuario' value={actualUserName} onChangeText={(text) => setUserName(text)}/>
                    <TextInput style={colorScheme === 'dark' ? usrStylesDark.changeEmailModelInput : usrStyles.changeEmailModelInput} placeholder='Introduce tu nuevo nombre de usuario' value={newUserName} onChangeText={(text) => setNewUserName(text)}/>
                    <TextInput style={colorScheme === 'dark' ? usrStylesDark.changeEmailModelInput : usrStyles.changeEmailModelInput} placeholder='Introduce tu contraseña' autoCapitalize='none' secureTextEntry={true} value={password} onChangeText={(text) => setPassword(text)}/>
                </View>
            </View>
        </Modal>
    )
}