import { Button, View, Modal, TextInput, Alert, Appearance} from 'react-native'
import { useState } from 'react'

import { authentication } from '../../../firebaseConfig'
import { signInWithEmailAndPassword, deleteUser } from "firebase/auth"
import {deleteDoc, doc} from 'firebase/firestore'

import usrStyles from '../usrStyles'
import usrStylesDark from '../usrStylesDark'

export default function DeleteAccModal(props) {

    const colorScheme = Appearance.getColorScheme()

    const [ password, setPassword ] = useState("")

    const closeModal = () => {
        setPassword("")
        props.setDeleteAccModal(!props.deleteAccModal)
    }

    const pushData = async () => {
        signInWithEmailAndPassword(authentication, authentication.currentUser.email, password)
        .then((re) => {
            Alert.alert(
                "Vas a eliminar tu cuenta permanentemente. ¿Deseas continuar?",
                "",
                [ { text: "Cancelar", style: "cancel" }, { text: "Continuar" , onPress: () => deleteAcc()} ]
            )
        })
        .catch((error) => {
            Alert.alert(
                "Tu contraseña no coincide",
                "Asegúrate de que has introducido correctamente tu contraseña",
                [ { text: "OK" } ]
            )
        })
    }

    const deleteAcc = async () => {
        await deleteDoc(doc(db, "users", authentication.currentUser.uid))
        deleteUser(authentication.currentUser).then(() => {
            closeModal()
            Alert.alert(
                "Se ha eliminado correctamente tu cuenta",
                "",
                [{ text: "OK" }]
            )
          }).catch((error) => {
            // An error ocurred
            // ...
            console.log(error);
          })
    }

    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={props.deleteAccModal}
            onRequestClose={() => { props.setDeleteAccModal(!props.deleteAccModal); }}
            >
            <View style={colorScheme === 'dark' ? usrStylesDark.changeEmailModelView : usrStyles.changeEmailModelView}>
                <View style={usrStyles.changeEmailModelViewButtons}>
                    <Button title="Cancelar" onPress={() => closeModal()}/>
                    <Button title="Confirmar" onPress={() => pushData()}/>  
                </View>
                <View style={usrStyles.changeEmailModelInputView}>
                    <TextInput style={colorScheme === 'dark' ? usrStylesDark.changeEmailModelInput : usrStyles.changeEmailModelInput} placeholder='Introduce tu contraseña' autoCapitalize='none' secureTextEntry={true} value={password} onChangeText={(text) => setPassword(text)}/>
                </View>
            </View>
        </Modal>
    )
}