import { View, Modal, Text, TouchableOpacity, Alert, Appearance } from 'react-native'
import { useState } from 'react'
import Ionicons from 'react-native-vector-icons/Ionicons'

import ChangeEmailModal from './ChangeEmailModal'
import ChangeUserNameModal from './ChangeUserNameModal'
import ChangePasswordModal from './ChangePasswordModal'
import DeleteAccModal from './DeleteAccModal'

import { authentication } from '../../../firebaseConfig'

import usrStyles from '../usrStyles'
import usrStylesDark from '../usrStylesDark'

export default function ProfileModal(props) {

    const colorScheme = Appearance.getColorScheme()
    
    const [ changeEmailModal, setChangeEmailModal ] = useState(false)
    const [ changeUserNameModal, setChangeUserNameModal ] = useState(false)
    const [ changePasswordModal, setChangePasswordModal ] = useState(false)
    const [ deleteAccModal, setDeleteAccModal ] = useState(false)

    const manageDeleteAcc = () => {
        Alert.alert(
            "¿Seguro que quieres eliminar tu cuenta permanentemente?",
            "Tus datos se perderán y no podrás volver a recuperarlos",
            [ { text: "Cancelar", style: "cancel" }, { text: "Eliminar" , onPress: () => setDeleteAccModal(!deleteAccModal)} ]
        )
    }

    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={props.profileModal}
            onRequestClose={() => { props.setProfileModal(!props.profileModal) }}
            >
            <View style={colorScheme === 'dark' ? usrStylesDark.modelView : usrStyles.modelView}>
                <TouchableOpacity style={{flexDirection: 'row', alignItems: 'center'}} onPress={() => props.setProfileModal(!props.profileModal)}>
                    <Ionicons name="ios-chevron-back" size={25} color={'#0080FE'} />
                    <Text style={{color: '#0080FE', fontSize: 16,}}>Perfil</Text>
                </TouchableOpacity>
                <View style={usrStyles.modelShowDataView}>
                    <Ionicons name="person-circle-outline" size={90} color={'gray'} />
                    <Text style={colorScheme === 'dark' ? usrStylesDark.yourNameText2 : usrStyles.yourNameText2}>{authentication.currentUser.displayName}</Text>
                    <Text style={usrStyles.emailText2}>{authentication.currentUser.email}</Text>
                </View>
                <View style={usrStyles.appPropsTextView}>
                    <Text style={usrStyles.appPropsText}>CONFIGURACIÓN DE TUS DATOS</Text>
                </View>
                <View style={colorScheme === 'dark' ? usrStylesDark.propsView2 : usrStyles.propsView2}>
                    <TouchableOpacity style={usrStyles.changeEmail} onPress={() => setChangeEmailModal(!changeEmailModal)}>
                        <Ionicons name="ios-at-circle" size={25} color={'green'} />
                        <Text style={colorScheme === 'dark' ? usrStylesDark.textModifyEmail : usrStyles.textModifyEmail}>Modifica tu dirección de correo</Text>
                        <View style={usrStyles.arrowLogoutView}>
                            <Ionicons name="chevron-forward-outline" size={25} color={'gray'} />
                        </View>
                    </TouchableOpacity>
                    <ChangeEmailModal changeEmailModal={changeEmailModal} setChangeEmailModal={setChangeEmailModal}/>
                    <View style={colorScheme === 'dark' ? usrStylesDark.separatorProfile2 : usrStyles.separatorProfile2}/>
                    <TouchableOpacity style={usrStyles.changeUserName} onPress={() => setChangeUserNameModal(!changeUserNameModal)}>
                        <Ionicons name="ios-person" size={25} color={'#0080FE'} />
                        <Text style={colorScheme === 'dark' ? usrStylesDark.textModifyPsw : usrStyles.textModifyPsw}>Modifica tu nombre de usuario</Text>
                        <View style={usrStyles.arrowLogoutView}>
                            <Ionicons name="chevron-forward-outline" size={25} color={'gray'} />
                        </View>
                    </TouchableOpacity>
                    <ChangeUserNameModal changeUserNameModal={changeUserNameModal} setChangeUserNameModal={setChangeUserNameModal}/>
                    <View style={colorScheme === 'dark' ? usrStylesDark.separatorProfile2 : usrStyles.separatorProfile2}/>
                    <TouchableOpacity style={usrStyles.changePassword} onPress={() => setChangePasswordModal(!changePasswordModal)}>
                        <Ionicons name="ios-lock-closed" size={25} color={'orange'} />
                        <Text style={colorScheme === 'dark' ? usrStylesDark.textModifyPsw : usrStyles.textModifyPsw}>Modifica tu contraseña</Text>
                        <View style={usrStyles.arrowLogoutView}>
                            <Ionicons name="chevron-forward-outline" size={25} color={'gray'} />
                        </View>
                    </TouchableOpacity>
                    <ChangePasswordModal changePasswordModal={changePasswordModal} setChangePasswordModal={setChangePasswordModal}/>
                </View>
                <View style={usrStyles.appPropsTextView}>
                    <Text style={usrStyles.appPropsText}>ELIMINACIÓN DE LA CUENTA</Text>
                </View>
                <View style={colorScheme === 'dark' ? usrStylesDark.propsView2 : usrStyles.propsView2}>
                    <TouchableOpacity style={usrStyles.deleteUser} onPress={() => manageDeleteAcc()}>
                        <Ionicons name="ios-close" size={25} color={'red'} />
                        <Text style={colorScheme === 'dark' ? usrStylesDark.textModifyEmail : usrStyles.textModifyEmail}>Elimina tu cuenta</Text>
                        <View style={usrStyles.arrowLogoutView}>
                            <Ionicons name="chevron-forward-outline" size={25} color={'red'} />
                        </View>
                    </TouchableOpacity>
                    <DeleteAccModal deleteAccModal={deleteAccModal} setDeleteAccModal={setDeleteAccModal}/>
                </View>
            </View>
            
        </Modal>
    )
}