import { Button, View, Modal, TextInput, Text, Alert, Appearance } from 'react-native'
import { useState } from 'react'
import DateTimePicker from '@react-native-community/datetimepicker'

import { authentication } from '../../../firebaseConfig'
import { db } from '../../../firebaseConfig'
import { setDoc, doc } from 'firebase/firestore'

import usrStyles from '../usrStyles'
import usrStylesDark from '../usrStylesDark'

export default function RecordsModal(props) {

    const colorScheme = Appearance.getColorScheme();

    const [ exerciseName, setExerciseName ] = useState("")
    const [ weight, setWeight ] = useState("")
    const [ recordDay, setRecordDay ] = useState(new Date())

    const closeModal = () => {
        setExerciseName("")
        setWeight("")
        setRecordDay(new Date())
        props.setRecordsModal(!props.recordsModal)
    }

    const onChange = (event, selectedDate) => {
        const currentDate = selectedDate
        setRecordDay(currentDate)
    }

    const checkRecord = () => {
        const weightRegex = new RegExp(/^\d{1,3}$|^\d{1,3},\d{1,2}$/g)
        if ( exerciseName == "" ) {
            Alert.alert(
                "Introduce un nombre para el ejercicio",
                "",
                [{ text: "OK" } ]
            )
        } else if ( weight == "" ) {
            Alert.alert(
                "Introduce algún peso para el ejercicio",
                "",
                [{ text: "OK" } ]
            )
        } else if ( !weightRegex.test(weight) ) {
            Alert.alert(
                "Formato incorrecto del record",
                "El peso de tu record ha de ser un número de 1 a 3 dígitos con o sin decimales, máx. 2 decimales",
                [ { text: "OK" } ]
            )
        } else {
            Alert.alert(
                "Vas a batir un record. ¿Deseas continuar?",
                "",
                [ { text: "Cancelar", style: "cancel" }, { text: "Continuar" , onPress: () => addRecord()} ]
            )
        }
    }

    const addRecord = async () => {
        await setDoc( doc(db, "users", authentication.currentUser.uid, "records", exerciseName,), {
            exerciseName: exerciseName, 
            weight: weight,
            recordDay: recordDay,
        })
        closeModal()
    }

    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={props.recordsModal}
            onRequestClose={() => { props.setRecordsModal(!props.recordsModal); }}
            >
            <View style={colorScheme === 'dark' ? usrStylesDark.modelRecordsView : usrStyles.modelRecordsView}>
                <View style={usrStyles.modelViewButtons}>
                    <Button title="Cancelar" onPress={() => closeModal()}/>
                    <Button title="Confirmar" onPress={() => checkRecord()}/>  
                </View>
                <View style={usrStyles.modelRecordsInputsView}>
                    <TextInput style={colorScheme === 'dark' ? usrStylesDark.modelRecordsInput : usrStyles.modelRecordsInput} placeholder='Nombre del ejercicio' value={exerciseName} onChangeText={(value) => setExerciseName(value)}/>
                    <TextInput style={colorScheme === 'dark' ? usrStylesDark.modelRecordsInput : usrStyles.modelRecordsInput} placeholder='Kg' keyboardType='numeric' maxLength={6} value={weight} onChangeText={(value) => setWeight(value)}/>
                </View>
                <View style={usrStyles.datePickerView}>
                    <Text style={colorScheme === 'dark' ? usrStylesDark.datePickerLabel : usrStyles.datePickerLabel}>Día que lo conseguiste:</Text>
                    <DateTimePicker
                            style={usrStyles.datePickerRecord}
                            testID="dateTimePicker"
                            value={recordDay}
                            mode='date'
                            is24Hour={true}
                            onChange={onChange}
                        />
                </View>
            </View>
        </Modal>
    )
}