import { View, Text, Alert , TouchableOpacity, Switch, FlatList, Appearance } from 'react-native'
import { useState, useEffect } from 'react';
import Ionicons from 'react-native-vector-icons/Ionicons';

import ProfileModal from './Modals/ProfileModal'
import RecordsModal from './Modals/RecordsModal'
import RecordCard from './UsersCards/RecordCard'
import StatsModal from './Modals/StatsModal';

import { authentication } from '../../firebaseConfig'
import { db } from '../../firebaseConfig'
import { collection, getDocs, onSnapshot} from 'firebase/firestore'
import { signOut } from 'firebase/auth'

import usrStyles from './usrStyles'
import usrStylesDark from './usrStylesDark'

export default function Profile() {

    const colorScheme = Appearance.getColorScheme()

    const [ profileModal, setProfileModal ] = useState(false)
    const [ statsModal, setStatsModal ] = useState(false)
    const [ recordsModal, setRecordsModal ] = useState(false)

    const darkTheme  = colorScheme === 'dark' ? "Activo" : "Inactivo"

    const [ recordsList, setRecordsList ] = useState()

    useEffect(() => {
        getData()
    }, [])

    const getData = async () => {
        const month = ["January","February","March","April","May","June","July","August","September","October","November","December"]
        onSnapshot(collection(db, "users", authentication.currentUser.uid, "records"), (querySnapshot) => {
            let records = []
            querySnapshot.forEach((doc) => {
                const date =  month[doc.data().recordDay.toDate().getMonth()].substring(0,3).toLocaleUpperCase() + " " + doc.data().recordDay.toDate().getDate()  + " | " + doc.data().recordDay.toDate().getFullYear()
                records.push({exerciseName: doc.data().exerciseName, weight: doc.data().weight, recordDay: date})
            })            
            setRecordsList(records)
        })
    }

    const logout = () => {
        Alert.alert(
            "¿Seguro que quieres salir?",
            "",
            [ { text: "Cancelar", style: "cancel" }, { text: "Salir" , onPress: () => onLogout()} ]
        )
    }

    const onLogout = () => {
        signOut(authentication).then(() => {
            // Sign-out successful.
          }).catch((error) => {
            // An error happened.
          })
    }

    const renderRecord = ({ item }) => (
        <RecordCard recordDay={item.recordDay} exerciseName={item.exerciseName} weight={item.weight}/>
    )

    const addRecord = () => {
        Alert.alert(
            "¿Quieres añadir una nueva marca?",
            "",
            [ { text: "Cancelar", style: "cancel" }, { text: "Añadir" , onPress: () => setRecordsModal(!recordsModal)} ]
        )
        
    }

    
  return (
    <View style={colorScheme === 'dark' ? usrStylesDark.profileView : usrStyles.profileView}>
        <View style={usrStyles.profileTitle}>
            <Text style={colorScheme === 'dark' ? usrStylesDark.profileTitleText : usrStyles.profileTitleText}>Perfil</Text>
        </View>
        <View style={colorScheme === 'dark' ? usrStylesDark.yourDataView : usrStyles.yourDataView}>
            <TouchableOpacity style={usrStyles.yourDataItemsView} onPress={ () => setProfileModal(!profileModal)}>
                <Ionicons name="person-circle-outline" size={70} color={'gray'} />
                <View style={usrStyles.namePrevView}>
                    <Text style={colorScheme === 'dark' ? usrStylesDark.yourNameText : usrStyles.yourNameText}>{authentication.currentUser.displayName}</Text>
                    <Text style={colorScheme === 'dark' ? usrStylesDark.yourDataText : usrStyles.yourDataText}>Email, Username, Password y Modificación de la cuenta</Text>
                </View>
                <View style={usrStyles.forwardIcon}>
                    <Ionicons name="chevron-forward-outline" size={25} color={'gray'} />
                </View>
            </TouchableOpacity>
            <ProfileModal profileModal={profileModal} setProfileModal={setProfileModal}/>
            <View style={colorScheme === 'dark' ? usrStylesDark.separatorProfile : usrStyles.separatorProfile}/>
            <View style={usrStyles.emailView}>
                <Text style={colorScheme === 'dark' ? usrStylesDark.emailText : usrStyles.emailText}>Email :</Text>
                <View style={usrStyles.emailTextView}>
                    <Text style={usrStyles.emailText2}>{authentication.currentUser.email}</Text>
                </View>
            </View>
        </View>  
        <View style={usrStyles.appPropsTextView}>
            <Text style={usrStyles.appPropsText}>PROPIEDADES DE LA APP</Text>
        </View>
        <View style={colorScheme === 'dark' ? usrStylesDark.propsView : usrStyles.propsView}>
            
            {/*
            <TouchableOpacity style={usrStyles.propsAlertView} onPress={() => setStatsModal(!statsModal)}>
                <Ionicons name="ios-body" size={25} color={'#89CFF0'} />          
                <Text style={colorScheme === 'dark' ? usrStylesDark.propsAlertViewText: usrStyles.propsAlertViewText}>Tu peso diario</Text>
                <View style={usrStyles.arrowLogoutView}>
                    <Ionicons name="chevron-forward-outline" size={25} color={'gray'} />
                </View>
            </TouchableOpacity>
            <StatsModal statsModal={statsModal} setStatsModal={setStatsModal}/>
            
            <View style={colorScheme === 'dark' ? usrStylesDark.separatorProfile2 : usrStyles.separatorProfile2}/>
            */}
            
            <View style={usrStyles.propsDarkThemeView}>
                {colorScheme === 'light' &&
                <Ionicons name="ios-sunny" size={25} color={'orange'} />
                }
                {colorScheme === 'dark' && 
                <Ionicons name="ios-moon" size={25} color={'#f2f1f6'} />
                }
                <Text style={colorScheme === 'dark' ? usrStylesDark.propsAlertViewText : usrStyles.propsAlertViewText}>Tema oscuro activo</Text>
                {colorScheme === 'dark' && 
                    <View style={usrStyles.switchThemeView}>
                        <Text style={{marginRight: 8, color: '#32CD32'}}>{darkTheme}</Text>
                    </View>
                }
                {colorScheme === 'light' && 
                    <View style={usrStyles.switchThemeView}>
                        <Text style={{marginRight: 8, color: 'gray'}}>{darkTheme}</Text>
                    </View>
                }
            </View>
            <View style={colorScheme === 'dark' ? usrStylesDark.separatorProfile2 : usrStyles.separatorProfile2}/>
            <TouchableOpacity style={usrStyles.exitView} onPress={() => logout()}>
                <Ionicons name="ios-exit-outline" size={25} color={'red'} style={{marginLeft: 3}}/>
                <Text style={colorScheme === 'dark' ? usrStylesDark.propsLogoutText : usrStyles.propsLogoutText}> Salir de la cuenta</Text>
                <View style={usrStyles.arrowLogoutView}>
                    <Ionicons name="chevron-forward-outline" size={25} color={'red'} />
                </View>
            </TouchableOpacity>
        </View>
        <View style={usrStyles.appPropsTextView}>
            <Text style={usrStyles.appPropsText}>TUS MARCAS PERSONALES ( PR )</Text>
            <TouchableOpacity onPress={() => addRecord()}>
                {colorScheme === 'light' && <Ionicons name="ios-add" size={23} color={'cian'} style={{marginLeft: 10}}/>}
                {colorScheme === 'dark' && <Ionicons name="ios-add" size={23} color={'white'} style={{marginLeft: 10}}/>}
            </TouchableOpacity>
            <RecordsModal recordsModal={recordsModal} setRecordsModal={setRecordsModal}/>
        </View>
        <View style={{width: '100%', marginLeft: 40, marginTop: 5,}}>
            <FlatList 
                data={recordsList}
                renderItem={renderRecord}
                key={item => item.id}
                horizontal={true}
            />
        </View>
    </View>
  )
}
