import { View, Text, Button, TextInput, Alert , Appearance } from 'react-native'
import React, { useState } from 'react'

import { authentication } from '../../firebaseConfig'
import { createUserWithEmailAndPassword, updateProfile } from "firebase/auth"

import usrStyles from './usrStyles'
import usrStylesDark from './usrStylesDark'

export default function Register(props) {

    const colorScheme = Appearance.getColorScheme()

    const [ user, setUser ] = useState("")
    const [ email, setEmail ] = useState("")
    const [ password, setPassword ] = useState("")
    const [ password2, setPassword2 ] = useState("")

    const checkRegister = () => {
        if ( user == "" ) {
            Alert.alert(
                "Introduce un nombre de usuario",
                "",
                [ { text: "OK" } ]
            )
        } else if ( email == "" ) {
            Alert.alert(
                "Introduce una dirección de correo electrónico",
                "",
                [ { text: "OK" } ]
            )
        } else if ( password == "" || password2 == "" ) {
            Alert.alert(
                "Introduce una contraseña",
                "",
                [ { text: "OK" } ]
            )
        } else {
            if ( password == password2) {
                onRegister(user, email, password)
            } else {
                Alert.alert(
                    "Las contraseñas no coinciden",
                    "Revisa que has introducido correctamente tus contraseñas",
                    [ { text: "OK" } ]
                )
            }
        }       
    }

    const onRegister = (user, email, password) => {
        createUserWithEmailAndPassword(authentication, email, password)
        .then(async (re) => {
            const displayName = user
            await updateProfile(authentication.currentUser, {displayName})
        })
        .catch((error) => {
            console.log(error.code)
            console.log(error.message)
            Alert.alert(
                "Registro fallido",
                "Error: " + error.code,
                [ { text: "OK" } ]
            )
        })
    }

  return (
    <View style={colorScheme === 'dark' ? usrStylesDark.loginView : usrStyles.loginView}>
        <View style={usrStyles.userParamsView}>
            <Text style={colorScheme === 'dark' ? usrStylesDark.userParamsLabel : usrStyles.userParamsLabel}>Nombre de usuario</Text>
            <TextInput style={colorScheme === 'dark' ? usrStylesDark.userParamsInput : usrStyles.userParamsInput} placeholder='Introduce tu nombre de usuario' value={user} onChangeText={(text) => setUser(text)}></TextInput>
        </View>
        <View style={usrStyles.userParamsView}>
            <Text style={colorScheme === 'dark' ? usrStylesDark.userParamsLabel : usrStyles.userParamsLabel}>Email</Text>
            <TextInput style={colorScheme === 'dark' ? usrStylesDark.userParamsInput : usrStyles.userParamsInput} placeholder='Introduce tu dirección de correo' autoCapitalize='none' keyboardType='email-address' value={email} onChangeText={(text) => setEmail(text)}></TextInput>
        </View>
        <View style={usrStyles.pswParamsView}>
            <Text style={colorScheme === 'dark' ? usrStylesDark.pswParamsLabel : usrStyles.pswParamsLabel}>Contraseña</Text>
            <TextInput style={colorScheme === 'dark' ? usrStylesDark.pswParamsInput : usrStyles.pswParamsInput} placeholder='Introduce tu contraseña' secureTextEntry={true} value={password} onChangeText={(text) => setPassword(text)}></TextInput>
            <Text style={colorScheme === 'dark' ? usrStylesDark.pswParamsLabel : usrStyles.pswParamsLabel}>Repetir Contraseña</Text>
            <TextInput style={colorScheme === 'dark' ? usrStylesDark.pswParamsInput : usrStyles.pswParamsInput} placeholder='Introduce tu contraseña' secureTextEntry={true} value={password2} onChangeText={(text) => setPassword2(text)}></TextInput>
        </View>
        
        <View style={usrStyles.btnConfirmar}>
            <Button title='Confirmar' onPress={() => checkRegister()}/>
        </View>
        <View style={usrStyles.botonera}>
            <Button title='Login' color={'gray'} onPress={() => props.setMode(!props.mode)}/>
        </View>
    </View>
  )
}